@@ -3,9 +3,9 @@
 /**
  * @file classes/tasks/SubscriptionExpiryReminder.inc.php
  *
- * Copyright (c) 2014-2016 Simon Fraser University Library
- * Copyright (c) 2003-2016 John Willinsky
- * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
+ * Copyright (c) 2014-2021 Simon Fraser University
+ * Copyright (c) 2003-2021 John Willinsky
+ * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @class SubscriptionExpiryReminder
  * @ingroup tasks
@@ -18,47 +18,45 @@ import('lib.pkp.classes.scheduledTask.ScheduledTask');
 class SubscriptionExpiryReminder extends ScheduledTask {
 
 	/**
-	 * Constructor.
-	 */
-	function SubscriptionExpiryReminder() {
-		$this->ScheduledTask();
-	}
-
-	/**
-	 * @see ScheduledTask::getName()
+	 * @copydoc ScheduledTask::getName()
 	 */
 	function getName() {
 		return __('admin.scheduledTask.subscriptionExpiryReminder');
 	}
 
-	function sendReminder ($subscription, $journal, $emailKey) {
-
-		$userDao = DAORegistry::getDAO('UserDAO');
-		$subscriptionTypeDao = DAORegistry::getDAO('SubscriptionTypeDAO');
+	/**
+	 * Send a particular subscription expiry reminder.
+	 * @param $subscription Subscription
+	 * @param $journal Journal
+	 * @param $emailKey string Email template key
+	 */
+	protected function sendReminder ($subscription, $journal, $emailKey) {
+		$userDao = DAORegistry::getDAO('UserDAO'); /* @var $userDao UserDAO */
+		$subscriptionTypeDao = DAORegistry::getDAO('SubscriptionTypeDAO'); /* @var $subscriptionTypeDao SubscriptionTypeDAO */
 
 		$journalName = $journal->getLocalizedName();
 		$user = $userDao->getById($subscription->getUserId());
 		if (!isset($user)) return false;
 
-		$subscriptionType = $subscriptionTypeDao->getSubscriptionType($subscription->getTypeId());
+		$subscriptionType = $subscriptionTypeDao->getById($subscription->getTypeId());
 
-		$subscriptionName = $journal->getSetting('subscriptionName');
-		$subscriptionEmail = $journal->getSetting('subscriptionEmail');
-		$subscriptionPhone = $journal->getSetting('subscriptionPhone');
-		$subscriptionMailingAddress = $journal->getSetting('subscriptionMailingAddress');
+		$subscriptionName = $journal->getData('subscriptionName');
+		$subscriptionEmail = $journal->getData('subscriptionEmail');
+		$subscriptionPhone = $journal->getData('subscriptionPhone');
+		$subscriptionMailingAddress = $journal->getData('subscriptionMailingAddress');
 
 		$subscriptionContactSignature = $subscriptionName;
 
 		AppLocale::requireComponents(LOCALE_COMPONENT_PKP_USER, LOCALE_COMPONENT_APP_COMMON);
-		
+
 		if ($subscriptionMailingAddress != '') {
 			$subscriptionContactSignature .= "\n" . $subscriptionMailingAddress;
 		}
 		if ($subscriptionPhone != '') {
-			$subscriptionContactSignature .= "\n" . AppLocale::Translate('user.phone') . ': ' . $subscriptionPhone;
+			$subscriptionContactSignature .= "\n" . __('user.phone') . ': ' . $subscriptionPhone;
 		}
 
-		$subscriptionContactSignature .= "\n" . AppLocale::Translate('user.email') . ': ' . $subscriptionEmail;
+		$subscriptionContactSignature .= "\n" . __('user.email') . ': ' . $subscriptionEmail;
 
 		$paramArray = array(
 			'subscriberName' => $user->getFullName(),
@@ -66,12 +64,13 @@ class SubscriptionExpiryReminder extends ScheduledTask {
 			'subscriptionType' => $subscriptionType->getSummaryString(),
 			'expiryDate' => $subscription->getDateEnd(),
 			'username' => $user->getUsername(),
-			'subscriptionContactSignature' => $subscriptionContactSignature 
+			'subscriptionContactSignature' => $subscriptionContactSignature
 		);
 
 		import('lib.pkp.classes.mail.MailTemplate');
 		$mail = new MailTemplate($emailKey, $journal->getPrimaryLocale(), $journal, false);
-		$mail->setReplyTo($subscriptionEmail, $subscriptionName);
+		$mail->setReplyTo(null);
+		$mail->setFrom($subscriptionEmail, $subscriptionName);
 		$mail->addRecipient($user->getEmail(), $user->getFullName());
 		$mail->setSubject($mail->getSubject($journal->getPrimaryLocale()));
 		$mail->setBody($mail->getBody($journal->getPrimaryLocale()));
@@ -79,19 +78,21 @@ class SubscriptionExpiryReminder extends ScheduledTask {
 		$mail->send();
 	}
 
-	function sendJournalReminders ($journal, $curDate) {
-
+	/**
+	 * Send a journal's subscription expiry reminders.
+	 * @param $journal Journal
+	 * @param $curDate array The current date
+	 */
+	protected function sendJournalReminders ($journal, $curDate) {
 		// Only send reminders if subscriptions are enabled
-		if ($journal->getSetting('publishingMode') == PUBLISHING_MODE_SUBSCRIPTION) {
+		if ($journal->getData('publishingMode') == PUBLISHING_MODE_SUBSCRIPTION) {
 
 			$curYear = $curDate['year'];
 			$curMonth = $curDate['month'];
 			$curDay = $curDate['day'];
 
 			// Check if expiry notification before months is enabled
-			if ($journal->getSetting('enableSubscriptionExpiryReminderBeforeMonths')) {
-
-				$beforeMonths = $journal->getSetting('numMonthsBeforeSubscriptionExpiryReminder');
+			if ($beforeMonths = $journal->getData('numMonthsBeforeSubscriptionExpiryReminder')) {
 				$beforeYears = (int)floor($beforeMonths/12);
 				$beforeMonths = (int)fmod($beforeMonths,12);
 
@@ -100,11 +101,11 @@ class SubscriptionExpiryReminder extends ScheduledTask {
 				$expiryDay = $curDay;
 
 				// Retrieve all subscriptions that match expiry date
-				$individualSubscriptionDao = DAORegistry::getDAO('IndividualSubscriptionDAO');
-				$institutionalSubscriptionDao = DAORegistry::getDAO('InstitutionalSubscriptionDAO');
+				$individualSubscriptionDao = DAORegistry::getDAO('IndividualSubscriptionDAO'); /* @var $individualSubscriptionDao IndividualSubscriptionDAO */
+				$institutionalSubscriptionDao = DAORegistry::getDAO('InstitutionalSubscriptionDAO'); /* @var $institutionalSubscriptionDao InstitutionalSubscriptionDAO */
 				$dateEnd = $expiryYear . '-' . $expiryMonth . '-' . $expiryDay;
-				$individualSubscriptions = $individualSubscriptionDao->getSubscriptionsByDateEnd($dateEnd, $journal->getId()); 
-				$institutionalSubscriptions = $institutionalSubscriptionDao->getSubscriptionsByDateEnd($dateEnd, $journal->getId()); 
+				$individualSubscriptions = $individualSubscriptionDao->getByDateEnd($dateEnd, $journal->getId());
+				$institutionalSubscriptions = $institutionalSubscriptionDao->getByDateEnd($dateEnd, $journal->getId());
 
 				while ($subscription = $individualSubscriptions->next()) {
 					$this->sendReminder($subscription, $journal, 'SUBSCRIPTION_BEFORE_EXPIRY');
@@ -116,22 +117,20 @@ class SubscriptionExpiryReminder extends ScheduledTask {
 			}
 
 			// Check if expiry notification before weeks is enabled
-			if ($journal->getSetting('enableSubscriptionExpiryReminderBeforeWeeks')) {
-
-				$beforeWeeks = $journal->getSetting('numWeeksBeforeSubscriptionExpiryReminder');
+			if ($beforeWeeks = $journal->getData('numWeeksBeforeSubscriptionExpiryReminder')) {
 				$beforeDays = $beforeWeeks * 7;
 
 				$expiryMonth = $curMonth + (int)floor(($curDay+$beforeDays)/31);
 				$expiryYear = $curYear + (int)floor($expiryMonth/12);
 				$expiryDay = (int)fmod($curDay+$beforeDays,31);
-				$expiryMonth = (int)fmod($expiryMonth,12);				
+				$expiryMonth = (int)fmod($expiryMonth,12);
 
 				// Retrieve all subscriptions that match expiry date
-				$individualSubscriptionDao = DAORegistry::getDAO('IndividualSubscriptionDAO');
-				$institutionalSubscriptionDao = DAORegistry::getDAO('InstitutionalSubscriptionDAO');
+				$individualSubscriptionDao = DAORegistry::getDAO('IndividualSubscriptionDAO'); /* @var $individualSubscriptionDao IndividualSubscriptionDAO */
+				$institutionalSubscriptionDao = DAORegistry::getDAO('InstitutionalSubscriptionDAO'); /* @var $institutionalSubscriptionDao InstitutionalSubscriptionDAO */
 				$dateEnd = $expiryYear . '-' . $expiryMonth . '-' . $expiryDay;
-				$individualSubscriptions = $individualSubscriptionDao->getSubscriptionsByDateEnd($dateEnd, $journal->getId()); 
-				$institutionalSubscriptions = $institutionalSubscriptionDao->getSubscriptionsByDateEnd($dateEnd, $journal->getId()); 
+				$individualSubscriptions = $individualSubscriptionDao->getByDateEnd($dateEnd, $journal->getId());
+				$institutionalSubscriptions = $institutionalSubscriptionDao->getByDateEnd($dateEnd, $journal->getId());
 
 				while ($subscription = $individualSubscriptions->next()) {
 					$this->sendReminder($subscription, $journal, 'SUBSCRIPTION_BEFORE_EXPIRY');
@@ -143,9 +142,7 @@ class SubscriptionExpiryReminder extends ScheduledTask {
 			}
 
 			// Check if expiry notification after months is enabled
-			if ($journal->getSetting('enableSubscriptionExpiryReminderAfterMonths')) {
-
-				$afterMonths = $journal->getSetting('numMonthsAfterSubscriptionExpiryReminder');
+			if ($afterMonths = $journal->getData('numMonthsAfterSubscriptionExpiryReminder')) {
 				$afterYears = (int)floor($afterMonths/12);
 				$afterMonths = (int)fmod($afterMonths,12);
 
@@ -160,11 +157,11 @@ class SubscriptionExpiryReminder extends ScheduledTask {
 				$expiryDay = $curDay;
 
 				// Retrieve all subscriptions that match expiry date
-				$individualSubscriptionDao = DAORegistry::getDAO('IndividualSubscriptionDAO');
-				$institutionalSubscriptionDao = DAORegistry::getDAO('InstitutionalSubscriptionDAO');
+				$individualSubscriptionDao = DAORegistry::getDAO('IndividualSubscriptionDAO'); /* @var $individualSubscriptionDao IndividualSubscriptionDAO */
+				$institutionalSubscriptionDao = DAORegistry::getDAO('InstitutionalSubscriptionDAO'); /* @var $institutionalSubscriptionDao InstitutionalSubscriptionDAO */
 				$dateEnd = $expiryYear . '-' . $expiryMonth . '-' . $expiryDay;
-				$individualSubscriptions = $individualSubscriptionDao->getSubscriptionsByDateEnd($dateEnd, $journal->getId()); 
-				$institutionalSubscriptions = $institutionalSubscriptionDao->getSubscriptionsByDateEnd($dateEnd, $journal->getId()); 
+				$individualSubscriptions = $individualSubscriptionDao->getByDateEnd($dateEnd, $journal->getId());
+				$institutionalSubscriptions = $institutionalSubscriptionDao->getByDateEnd($dateEnd, $journal->getId());
 
 				while ($subscription = $individualSubscriptions->next()) {
 					$this->sendReminder($subscription, $journal, 'SUBSCRIPTION_AFTER_EXPIRY_LAST');
@@ -176,9 +173,7 @@ class SubscriptionExpiryReminder extends ScheduledTask {
 			}
 
 			// Check if expiry notification after weeks is enabled
-			if ($journal->getSetting('enableSubscriptionExpiryReminderAfterWeeks')) {
-
-				$afterWeeks = $journal->getSetting('numWeeksAfterSubscriptionExpiryReminder');
+			if ($afterWeeks = $journal->getData('numWeeksAfterSubscriptionExpiryReminder')) {
 				$afterDays = $afterWeeks * 7;
 
 				if (($curDay - $afterDays) <= 0) {
@@ -200,11 +195,11 @@ class SubscriptionExpiryReminder extends ScheduledTask {
 				$expiryYear = $curYear - $afterYears;
 
 				// Retrieve all subscriptions that match expiry date
-				$individualSubscriptionDao = DAORegistry::getDAO('IndividualSubscriptionDAO');
-				$institutionalSubscriptionDao = DAORegistry::getDAO('InstitutionalSubscriptionDAO');
+				$individualSubscriptionDao = DAORegistry::getDAO('IndividualSubscriptionDAO'); /* @var $individualSubscriptionDao IndividualSubscriptionDAO */
+				$institutionalSubscriptionDao = DAORegistry::getDAO('InstitutionalSubscriptionDAO'); /* @var $institutionalSubscriptionDao InstitutionalSubscriptionDAO */
 				$dateEnd = $expiryYear . '-' . $expiryMonth . '-' . $expiryDay;
-				$individualSubscriptions = $individualSubscriptionDao->getSubscriptionsByDateEnd($dateEnd, $journal->getId()); 
-				$institutionalSubscriptions = $institutionalSubscriptionDao->getSubscriptionsByDateEnd($dateEnd, $journal->getId()); 
+				$individualSubscriptions = $individualSubscriptionDao->getByDateEnd($dateEnd, $journal->getId());
+				$institutionalSubscriptions = $institutionalSubscriptionDao->getByDateEnd($dateEnd, $journal->getId());
 
 				while ($subscription = $individualSubscriptions->next()) {
 					$this->sendReminder($subscription, $journal, 'SUBSCRIPTION_AFTER_EXPIRY');
@@ -218,10 +213,10 @@ class SubscriptionExpiryReminder extends ScheduledTask {
 	}
 
 	/**
-	 * @see ScheduledTask::executeActions()
+	 * @copydoc ScheduledTask::executeActions()
 	 */
 	protected function executeActions() {
-		$journalDao = DAORegistry::getDAO('JournalDAO');
+		$journalDao = DAORegistry::getDAO('JournalDAO'); /* @var $journalDao JournalDAO */
 		$journals = $journalDao->getAll(true);
 
 		$todayDate = array(
@@ -238,21 +233,21 @@ class SubscriptionExpiryReminder extends ScheduledTask {
 		// If it is the first day of a month but previous month had only
 		// 30 days then simulate 31st day for expiry dates that end on
 		// that day.
-		$shortMonths = array(2,4,6,8,10,12);
+		$shortMonths = array(2,4,6,9,11);
 
 		if (($todayDate['day'] == 1) && in_array(($todayDate['month'] - 1), $shortMonths)) {
 
 			$curDate['day'] = 31;
 			$curDate['month'] = $todayDate['month'] - 1;
 
-			if ($curDate['month'] == 12) {
+			if ($curDate['month'] == 0) {
+				$curDate['month'] = 12;
 				$curDate['year'] = $todayDate['year'] - 1;
 			} else {
 				$curDate['year'] = $todayDate['year'];
 			}
 
 			$journals = $journalDao->getAll(true);
-
 			while ($journal = $journals->next()) {
 				// Send reminders for simulated 31st day of short month
 				$this->sendJournalReminders($journal, $curDate);
@@ -268,7 +263,6 @@ class SubscriptionExpiryReminder extends ScheduledTask {
 			$curDate['year'] = $todayDate['year'];
 
 			$journals = $journalDao->getAll(true);
-
 			while ($journal = $journals->next()) {
 				// Send reminders for simulated 30th day of February
 				$this->sendJournalReminders($journal, $curDate);
@@ -287,7 +281,8 @@ class SubscriptionExpiryReminder extends ScheduledTask {
 				}
 			}
 		}
+		return true;
 	}
 }
 
-?>
+
