@@ -3,9 +3,9 @@
 /**
  * @file controllers/grid/pubIds/form/AssignPublicIdentifiersForm.inc.php
  *
- * Copyright (c) 2014-2019 Simon Fraser University
- * Copyright (c) 2003-2019 John Willinsky
- * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
+ * Copyright (c) 2014-2021 Simon Fraser University
+ * Copyright (c) 2003-2021 John Willinsky
+ * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @class AssignPublicIdentifiersForm
  * @ingroup controllers_grid_pubIds_form
@@ -39,10 +39,10 @@ class AssignPublicIdentifiersForm extends PKPAssignPublicIdentifiersForm {
 	/**
 	 * @copydoc Form::fetch()
 	 */
-	function fetch($request) {
+	function fetch($request, $template = null, $display = false) {
 		$templateMgr = TemplateManager::getManager($request);
 		$templateMgr->assign('formParams', $this->getFormParams());
-		return parent::fetch($request);
+		return parent::fetch($request, $template, $display);
 	}
 
 	//
