@@ -3,9 +3,9 @@
 /**
  * @file controllers/tab/workflow/ReviewRoundTabHandler.inc.php
  *
- * Copyright (c) 2014-2016 Simon Fraser University Library
- * Copyright (c) 2003-2016 John Willinsky
- * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
+ * Copyright (c) 2014-2021 Simon Fraser University
+ * Copyright (c) 2003-2021 John Willinsky
+ * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @class ReviewRoundTabHandler
  * @ingroup controllers_tab_workflow
@@ -23,8 +23,8 @@ class ReviewRoundTabHandler extends PKPReviewRoundTabHandler {
 	/**
 	 * Constructor
 	 */
-	function ReviewRoundTabHandler() {
-		parent::PKPReviewRoundTabHandler();
+	function __construct() {
+		parent::__construct();
 		$this->addRoleAssignment(
 			array(ROLE_ID_SUB_EDITOR, ROLE_ID_MANAGER, ROLE_ID_ASSISTANT),
 			array('externalReviewRound')
@@ -48,4 +48,4 @@ class ReviewRoundTabHandler extends PKPReviewRoundTabHandler {
 	}
 }
 
-?>
+
