@@ -3,9 +3,9 @@
 /**
  * @file classes/controllers/grid/LiteralGridCellProvider.inc.php
  *
- * Copyright (c) 2014-2016 Simon Fraser University Library
- * Copyright (c) 2000-2016 John Willinsky
- * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
+ * Copyright (c) 2014-2021 Simon Fraser University
+ * Copyright (c) 2000-2021 John Willinsky
+ * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @class LiteralGridCellProvider
  * @ingroup controllers_grid
@@ -16,12 +16,6 @@
 import('lib.pkp.classes.controllers.grid.GridCellProvider');
 
 class LiteralGridCellProvider extends GridCellProvider {
-	/**
-	 * Constructor
-	 */
-	function LiteralGridCellProvider() {
-		parent::GridCellProvider();
-	}
 
 	//
 	// Template methods from GridCellProvider
@@ -45,4 +39,4 @@ class LiteralGridCellProvider extends GridCellProvider {
 	}
 }
 
-?>
+
