@@ -9,9 +9,9 @@
 /**
  * @file classes/file/FileManager.inc.php
  *
- * Copyright (c) 2014-2016 Simon Fraser University Library
- * Copyright (c) 2000-2016 John Willinsky
- * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
+ * Copyright (c) 2014-2021 Simon Fraser University
+ * Copyright (c) 2000-2021 John Willinsky
+ * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  * ePUB mime type added  Leah M Root (rootl) SUNY Geneseo
  * @class FileManager
  * @ingroup file
@@ -24,19 +24,21 @@ define('FILE_MODE_MASK', 0666);
 define('DIRECTORY_MODE_MASK', 0777);
 
 define('DOCUMENT_TYPE_DEFAULT', 'default');
+define('DOCUMENT_TYPE_AUDIO', 'audio');
 define('DOCUMENT_TYPE_EXCEL', 'excel');
 define('DOCUMENT_TYPE_HTML', 'html');
 define('DOCUMENT_TYPE_IMAGE', 'image');
 define('DOCUMENT_TYPE_PDF', 'pdf');
 define('DOCUMENT_TYPE_WORD', 'word');
 define('DOCUMENT_TYPE_EPUB', 'epub');
+define('DOCUMENT_TYPE_VIDEO', 'video');
 define('DOCUMENT_TYPE_ZIP', 'zip');
 
 class FileManager {
 	/**
 	 * Constructor
 	 */
-	function FileManager() {
+	function __construct() {
 	}
 
 	/**
@@ -58,7 +60,26 @@ class FileManager {
 	 * @return boolean
 	 */
 	function uploadError($fileName) {
-		return (isset($_FILES[$fileName]) && $_FILES[$fileName]['error'] != 0);
+		return (isset($_FILES[$fileName]) && $_FILES[$fileName]['error'] != UPLOAD_ERR_OK);
+	}
+
+	/**
+	 * Get the error code of a file upload
+	 * @see http://php.net/manual/en/features.file-upload.errors.php
+	 * @param $fileName string the name of the file used in the POST form
+	 * @return integer
+	 */
+	function getUploadErrorCode($fileName) {
+		return $_FILES[$fileName]['error'];
+	}
+
+	/**
+	 * Get the filename of the first uploaded file in the $_FILES array. The
+	 * returned filename is the value used in the form that submitted the request.
+	 * @return string
+	 */
+	function getFirstUploadedPostName() {
+		return key($_FILES);
 	}
 
 	/**
@@ -92,7 +113,14 @@ class FileManager {
 	 */
 	function getUploadedFileType($fileName) {
 		if (isset($_FILES[$fileName])) {
-			$type = PKPString::mime_content_type($_FILES[$fileName]['tmp_name']);
+			// The result of "explode" can't be passed directly to "array_pop" in PHP 7.
+			$exploded = explode('.',$_FILES[$fileName]['name']);
+
+			$type = PKPString::mime_content_type(
+				$_FILES[$fileName]['tmp_name'], // Location on server
+				array_pop($exploded) // Extension on client machine
+			);
+
 			if (!empty($type)) return $type;
 			return $_FILES[$fileName]['type'];
 		}
@@ -146,7 +174,6 @@ class FileManager {
 	 * @return boolean returns true if successful
 	 */
 	function copyFile($source, $dest) {
-		$success = true;
 		$destDir = dirname($dest);
 		if (!$this->fileExists($destDir, 'dir')) {
 			// Try to create the destination directory
@@ -224,13 +251,13 @@ class FileManager {
 	 * Outputs HTTP headers and file content for download
 	 * @param $filePath string the location of the file to be sent
 	 * @param $mediaType string the MIME type of the file, optional
-	 * @param $inline print file as inline instead of attachment, optional
+	 * @param $inline boolean print file as inline instead of attachment, optional
+	 * @param $fileName string Optional filename to use on the client side
 	 * @return boolean
 	 */
-	function downloadFile($filePath, $mediaType = null, $inline = false, $fileName = null) {
+	function downloadByPath($filePath, $mediaType = null, $inline = false, $fileName = null) {
 		$result = null;
 		if (HookRegistry::call('FileManager::downloadFile', array(&$filePath, &$mediaType, &$inline, &$result, &$fileName))) return $result;
-		$postDownloadHookList = array('FileManager::downloadFileFinished', 'UsageEventPlugin::getUsageEvent');
 		if (is_readable($filePath)) {
 			if ($mediaType === null) {
 				// If the media type wasn't specified, try to detect.
@@ -242,37 +269,19 @@ class FileManager {
 				$fileName = basename($filePath);
 			}
 
-			// Free some memory
-			$postDownloadHooks = null;
-			$hooks = HookRegistry::getHooks();
-			foreach ($postDownloadHookList as $hookName) {
-				if (isset($hooks[$hookName])) {
-					$postDownloadHooks[$hookName] = $hooks[$hookName];
-				}
-			}
-			unset($hooks);
-			Registry::clear();
-
 			// Stream the file to the end user.
 			header("Content-Type: $mediaType");
 			header('Content-Length: ' . filesize($filePath));
+			header('Accept-Ranges: none');
 			header('Content-Disposition: ' . ($inline ? 'inline' : 'attachment') . "; filename=\"$fileName\"");
 			header('Cache-Control: private'); // Workarounds for IE weirdness
 			header('Pragma: public');
-
 			$this->readFileFromPath($filePath, true);
-
-			if ($postDownloadHooks) {
-				foreach ($postDownloadHooks as $hookName => $hooks) {
-					HookRegistry::setHooks($hookName, $hooks);
-				}
-			}
 			$returner = true;
 		} else {
 			$returner = false;
 		}
 		HookRegistry::call('FileManager::downloadFileFinished', array(&$returner));
-
 		return $returner;
 	}
 
@@ -281,7 +290,7 @@ class FileManager {
 	 * @param $filePath string the location of the file to be deleted
 	 * @return boolean returns true if successful
 	 */
-	function deleteFile($filePath) {
+	function deleteByPath($filePath) {
 		if ($this->fileExists($filePath)) {
 			$result = null;
 			if (HookRegistry::call('FileManager::deleteFile', array($filePath, &$result))) return $result;
@@ -318,6 +327,7 @@ class FileManager {
 	/**
 	 * Delete all contents including directory (equivalent to "rm -r")
 	 * @param $file string the full path of the directory to be removed
+	 * @return boolean true iff success, otherwise false
 	 */
 	function rmtree($file) {
 		if (file_exists($file)) {
@@ -325,16 +335,17 @@ class FileManager {
 				$handle = opendir($file);
 				while (($filename = readdir($handle)) !== false) {
 					if ($filename != '.' && $filename != '..') {
-						$this->rmtree($file . '/' . $filename);
+						if (!$this->rmtree($file . '/' . $filename)) return false;
 					}
 				}
 				closedir($handle);
-				rmdir($file);
+				if (!rmdir($file)) return false;
 
 			} else {
-				unlink($file);
+				if (!unlink($file)) return false;
 			}
 		}
+		return true;
 	}
 
 	/**
@@ -422,6 +433,8 @@ class FileManager {
 				return '.pdf';
 			case 'application/word':
 				return '.doc';
+			case 'text/css':
+				return '.css';
 			case 'text/html':
 				return '.html';
 			case 'application/epub+zip':
@@ -451,6 +464,9 @@ class FileManager {
 			case 'image/x-ico':
 			case 'image/ico':
 				return '.ico';
+			case 'image/svg+xml':
+			case 'image/svg':
+				return '.svg';
 			case 'application/x-shockwave-flash':
 				return '.swf';
 			case 'video/x-flv':
@@ -542,27 +558,30 @@ class FileManager {
 			$fileExtension = 'txt';
 		}
 
+		// consider .tar.gz extension
+		if (strtolower(substr($fileName, -7)) == '.tar.gz') {
+			$fileExtension = substr($fileName, -6);
+		}
+
 		return $fileExtension;
 	}
 
 	/**
 	 * Decompress passed gziped file.
 	 * @param $filePath string
-	 * @param $errorMsg string
-	 * @return boolean|string
+	 * @return string The file path that was created.
 	 */
-	function decompressFile($filePath, &$errorMsg) {
-		return $this->_executeGzip($filePath, true, $errorMsg);
+	function decompressFile($filePath) {
+		return $this->_executeGzip($filePath, true);
 	}
 
 	/**
 	 * Compress passed file.
 	 * @param $filePath string The file to be compressed.
-	 * @param $errorMsg string
-	 * @return boolean|string
+	 * @return string The file path that was created.
 	 */
-	function compressFile($filePath, &$errorMsg) {
-		return $this->_executeGzip($filePath, false, $errorMsg);
+	function compressFile($filePath) {
+		return $this->_executeGzip($filePath, false);
 	}
 
 
@@ -574,31 +593,27 @@ class FileManager {
 	 * @param $filePath string file to be compressed or uncompressed.
 	 * @param $decompress boolean optional Set true if the passed file
 	 * needs to be decompressed.
-	 * @param $errorMsg string
-	 * @return false|string The file path that was created with the operation
-	 * or false in case of fail.
+	 * @return string The file path that was created with the operation
 	 */
-	private function _executeGzip($filePath, $decompress = false, &$errorMsg) {
+	private function _executeGzip($filePath, $decompress = false) {
 		PKPLocale::requireComponents(LOCALE_COMPONENT_PKP_ADMIN);
 		$gzipPath = Config::getVar('cli', 'gzip');
 		if (!is_executable($gzipPath)) {
-			$errorMsg = __('admin.error.executingUtil', array('utilPath' => $gzipPath, 'utilVar' => 'gzip'));
-			return false;
+			throw new Exception(__('admin.error.executingUtil', array('utilPath' => $gzipPath, 'utilVar' => 'gzip')));
 		}
 		$gzipCmd = escapeshellarg($gzipPath);
 		if ($decompress) $gzipCmd .= ' -d';
 		// Make sure any output message will mention the file path.
 		$output = array($filePath);
 		$returnValue = 0;
-		$gzipCmd .= ' ' . $filePath;
+		$gzipCmd .= ' ' . escapeshellarg($filePath);
 		if (!Core::isWindows()) {
 			// Get the output, redirecting stderr to stdout.
 			$gzipCmd .= ' 2>&1';
 		}
 		exec($gzipCmd, $output, $returnValue);
 		if ($returnValue > 0) {
-			$errorMsg = __('admin.error.utilExecutionProblem', array('utilPath' => $gzipPath, 'output' => implode(PHP_EOL, $output)));
-			return false;
+			throw new Exception(__('admin.error.utilExecutionProblem', array('utilPath' => $gzipPath, 'output' => implode(PHP_EOL, $output))));
 		}
 		if ($decompress) {
 			return substr($filePath, 0, -3);
@@ -607,5 +622,3 @@ class FileManager {
 		}
 	}
 }
-
-?>
