@@ -3,9 +3,9 @@
 /**
  * @file classes/form/validation/FormValidatorLocaleEmail.inc.php
  *
- * Copyright (c) 2014-2016 Simon Fraser University Library
- * Copyright (c) 2000-2016 John Willinsky
- * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
+ * Copyright (c) 2014-2021 Simon Fraser University
+ * Copyright (c) 2000-2021 John Willinsky
+ * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @class FormValidatorLocaleEmail
  * @ingroup form_validation
@@ -26,10 +26,10 @@ class FormValidatorLocaleEmail extends FormValidatorLocale {
 	 * @param $message string the error message for validation failures (i18n key)
 	 * @param $requiredLocale string The symbolic name of the required locale
 	 */
-	function FormValidatorLocaleEmail(&$form, $field, $type, $message, $requiredLocale = null) {
+	function __construct(&$form, $field, $type, $message, $requiredLocale = null) {
 		$validator = new ValidatorEmail();
-		parent::FormValidatorLocale($form, $field, $type, $message, $requiredLocale, $validator);
+		parent::__construct($form, $field, $type, $message, $requiredLocale, $validator);
 	}
 }
 
-?>
+
