@@ -3,9 +3,9 @@
 /**
  * @file classes/handler/PKPHandler.inc.php
  *
- * Copyright (c) 2014-2016 Simon Fraser University Library
- * Copyright (c) 2000-2016 John Willinsky
- * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
+ * Copyright (c) 2014-2021 Simon Fraser University
+ * Copyright (c) 2000-2021 John Willinsky
+ * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @package core
  * @class PKPHandler
@@ -15,6 +15,9 @@
  */
 
 class PKPHandler {
+	/** @var string|null API token */
+	protected $_apiToken = null;
+
 	/**
 	 * @var string identifier of the controller instance - must be unique
 	 *  among all instances of a given controller type.
@@ -40,15 +43,28 @@ class PKPHandler {
 	/** @var AuthorizationDecisionManager authorization decision manager for this handler */
 	var $_authorizationDecisionManager;
 
+	/** @var boolean Whether to enforce site access restrictions. */
+	var $_enforceRestrictedSite = true;
+
+	/** @var boolean Whether role assignments have been checked. */
+	var $_roleAssignmentsChecked = false;
+
+	/** @var boolean Whether this is a handler for a page in the backend editorial UI */
+	var $_isBackendPage = false;
+
 	/**
 	 * Constructor
 	 */
-	function PKPHandler() {
+	function __construct() {
 	}
 
 	//
 	// Setters and Getters
 	//
+	function setEnforceRestrictedSite($enforceRestrictedSite) {
+		$this->_enforceRestrictedSite = $enforceRestrictedSite;
+	}
+
 	/**
 	 * Set the controller id
 	 * @param $id string
@@ -123,8 +139,13 @@ class PKPHandler {
 	}
 
 	/**
-	 * Retrieve authorized context objects from the
-	 * decision manager.
+	 * Retrieve authorized context objects from the decision manager.
+	 * 
+	 * Gets an object that was previously stored using the same assoc type.
+	 * The authorization policies populate these -- when an object is fetched
+	 * and checked for permission in the policy class, it's then chucked into
+	 * the authorized context for later retrieval by code that needs it.
+	 * 
 	 * @param $assocType integer any of the ASSOC_TYPE_* constants
 	 * @return mixed
 	 */
@@ -154,7 +175,9 @@ class PKPHandler {
 	 * @return string
 	 */
 	function getLastAuthorizationMessage() {
-		assert(is_a($this->_authorizationDecisionManager, 'AuthorizationDecisionManager'));
+		if (!is_a($this->_authorizationDecisionManager, 'AuthorizationDecisionManager')) {
+			return '';
+		}
 		$authorizationMessages = $this->_authorizationDecisionManager->getAuthorizationMessages();
 		return end($authorizationMessages);
 	}
@@ -189,6 +212,9 @@ class PKPHandler {
 				$operations
 			);
 		}
+
+		// Flag role assignments as needing checking.
+		$this->_roleAssignmentsChecked = false;
 	}
 
 	/**
@@ -216,6 +242,13 @@ class PKPHandler {
 		return $this->_roleAssignments;
 	}
 
+	/**
+	 * Flag role assignment checking as completed.
+	 */
+	function markRoleAssignmentsChecked() {
+		$this->_roleAssignmentsChecked = true;
+	}
+
 	/**
 	 * Authorize this request.
 	 *
@@ -230,12 +263,11 @@ class PKPHandler {
 	 * @param $args array request arguments
 	 * @param $roleAssignments array the operation role assignment,
 	 *  see getRoleAssignment() for more details.
-	 * @param $enforceRestrictedSite boolean True iff site restrictions are to be enforced
 	 * @return boolean
 	 */
-	function authorize($request, &$args, $roleAssignments, $enforceRestrictedSite = true) {
+	function authorize($request, &$args, $roleAssignments) {
 		// Enforce restricted site access if required.
-		if ($enforceRestrictedSite) {
+		if ($this->_enforceRestrictedSite) {
 			import('lib.pkp.classes.security.authorization.RestrictedSiteAccessPolicy');
 			$this->addPolicy(new RestrictedSiteAccessPolicy($request), true);
 		}
@@ -249,7 +281,7 @@ class PKPHandler {
 		if (!defined('SESSION_DISABLE_INIT')) {
 			// Add user roles in authorized context.
 			$user = $request->getUser();
-			if (is_a($user, 'User')) {
+			if (is_a($user, 'User') || is_a($request->getRouter(), 'APIRouter')) {
 				import('lib.pkp.classes.security.authorization.UserRolesRequiredPolicy');
 				$this->addPolicy(new UserRolesRequiredPolicy($request), true);
 			}
@@ -275,7 +307,7 @@ class PKPHandler {
 
 		// Let the authorization decision manager take a decision.
 		$decision = $this->_authorizationDecisionManager->decide();
-		if ($decision == AUTHORIZATION_PERMIT) {
+		if ($decision == AUTHORIZATION_PERMIT && (empty($this->_roleAssignments) || $this->_roleAssignmentsChecked)) {
 			return true;
 		} else {
 			return false;
@@ -331,9 +363,8 @@ class PKPHandler {
 	 * authorization.
 	 *
 	 * @param $request PKPRequest
-	 * @param $args array
 	 */
-	function initialize($request, $args = null) {
+	function initialize($request) {
 		// Set the controller id to the requested
 		// page (page routing) or component name
 		// (component routing) by default.
@@ -346,6 +377,8 @@ class PKPHandler {
 			// becomes "grid-citation-citationgrid"
 			$componentId = str_replace('.', '-', PKPString::strtolower(PKPString::substr($componentId, 0, -7)));
 			$this->setId($componentId);
+		} elseif (is_a($router, 'APIRouter')) {
+			$this->setId($router->getEntity());
 		} else {
 			assert(is_a($router, 'PKPPageRouter'));
 			$this->setId($router->getRequestedPage($request));
@@ -388,7 +421,7 @@ class PKPHandler {
 			}
 		}
 
-		if ($context) $count = $context->getSetting('itemsPerPage');
+		if ($context) $count = $context->getData('itemsPerPage');
 		if (!isset($count)) $count = Config::getVar('interface', 'items_per_page');
 
 		import('lib.pkp.classes.db.DBResultRange');
@@ -434,6 +467,11 @@ class PKPHandler {
 
 		$accessibleWorkflowStages = $this->getAuthorizedContextObject(ASSOC_TYPE_ACCESSIBLE_WORKFLOW_STAGES);
 		if ($accessibleWorkflowStages) $templateMgr->assign('accessibleWorkflowStages', $accessibleWorkflowStages);
+
+		// Set up template requirements for the backend editorial UI
+		if ($this->_isBackendPage) {
+			$templateMgr->setupBackendPage();
+		}
 	}
 
 	/**
@@ -453,22 +491,6 @@ class PKPHandler {
 		);
 	}
 
-	/**
-	 * Get the iterator of working contexts.
-	 * @param $request PKPRequest
-	 * @return ItemIterator
-	 */
-	function getWorkingContexts($request) {
-		// For installation process
-		if (defined('SESSION_DISABLE_INIT') || !Config::getVar('general', 'installed')) {
-			return null;
-		}
-
-		$user = $request->getUser();
-		$contextDao = Application::getContextDAO();
-		return $contextDao->getAvailable($user?$user->getId():null);
-	}
-
 	/**
 	 * Return the context that is configured in site redirect setting.
 	 * @param $request Request
@@ -490,7 +512,7 @@ class PKPHandler {
 	 * @return mixed Either Context or null
 	 */
 	function getFirstUserContext($user, $contexts) {
-		$userGroupDao = DAORegistry::getDAO('UserGroupDAO');
+		$userGroupDao = DAORegistry::getDAO('UserGroupDAO'); /* @var $userGroupDao UserGroupDAO */
 		$context = null;
 		foreach($contexts as $workingContext) {
 			$userIsEnrolled = $userGroupDao->userInAnyGroup($user->getId(), $workingContext->getId());
@@ -509,6 +531,66 @@ class PKPHandler {
 	function requireSSL() {
 		return true;
 	}
+
+	/**
+	 * Return API token string
+	 *
+	 * @return string|null
+	 */
+	public function getApiToken() {
+		return $this->_apiToken;
+	}
+
+	/**
+	 * Set API token string
+	 *
+	 */
+	public function setApiToken($apiToken) {
+		return $this->_apiToken = $apiToken;
+	}
+
+	/**
+	 * Returns a "best-guess" context, based in the request data, if
+	 * a request needs to have one in its context but may be in a site-level
+	 * context as specified in the URL.
+	 * @param $request Request
+	 * @param $hasNoContexts boolean Optional reference to receive true iff no contexts were found.
+	 * @return mixed Either a Context or null if none could be determined.
+	 */
+	function getTargetContext($request, &$hasNoContexts = null) {
+		// Get the requested path.
+		$router = $request->getRouter();
+		$requestedPath = $router->getRequestedContextPath($request);
+
+		if ($requestedPath === 'index' || $requestedPath === '') {
+			// No context requested. Check how many contexts the site has.
+			$contextDao = Application::getContextDAO(); /* @var $contextDao ContextDAO */
+			$contexts = $contextDao->getAll(true);
+			list($firstContext, $secondContext) = [$contexts->next(), $contexts->next()];
+			if ($firstContext && !$secondContext) {
+				// Return the unique context.
+				$context = $firstContext;
+				$hasNoContexts = false;
+			} elseif ($firstContext && $secondContext) {
+				// Get the site redirect.
+				$context = $this->getSiteRedirectContext($request);
+				$hasNoContexts = false;
+			} else {
+				$context = null;
+				$hasNoContexts = true;
+			}
+		} else {
+			// Return the requested context.
+			$context = $router->getContext($request);
+
+			// If the specified context does not exist, respond with a 404.
+			if (!$context) $request->getDispatcher()->handle404();
+		}
+		if (is_a($context, 'Context')) {
+			return $context;
+		}
+		return null;
+	}
 }
 
-?>
+
