@@ -3,9 +3,9 @@
 /**
  * @file classes/install/Installer.inc.php
  *
- * Copyright (c) 2014-2016 Simon Fraser University Library
- * Copyright (c) 2000-2016 John Willinsky
- * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
+ * Copyright (c) 2014-2021 Simon Fraser University
+ * Copyright (c) 2000-2021 John Willinsky
+ * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @class Installer
  * @ingroup install
@@ -29,7 +29,8 @@ import('lib.pkp.classes.site.Version');
 import('lib.pkp.classes.site.VersionDAO');
 import('lib.pkp.classes.config.ConfigParser');
 
-require_once './lib/pkp/lib/adodb/adodb-xmlschema.inc.php';
+use Illuminate\Database\Capsule\Manager as Capsule;
+use Illuminate\Database\Schema\Blueprint;
 
 class Installer {
 
@@ -48,9 +49,6 @@ class Installer {
 	/** @var Version version after installation */
 	var $newVersion;
 
-	/** @var ADOConnection database connection */
-	var $dbconn;
-
 	/** @var string default locale */
 	var $locale;
 
@@ -84,6 +82,8 @@ class Installer {
 	/** @var Logger logging object */
 	var $logger;
 
+	/** @var array List of migrations executed already */
+	var $migrations = [];
 
 	/**
 	 * Constructor.
@@ -91,7 +91,7 @@ class Installer {
 	 * @param $params array installer parameters
 	 * @param $isPlugin boolean true iff a plugin is being installed
 	 */
-	function Installer($descriptor, $params = array(), $isPlugin = false) {
+	function __construct($descriptor, $params = array(), $isPlugin = false) {
 		// Load all plugins. If any of them use installer hooks,
 		// they'll need to be loaded here.
 		PluginRegistry::loadAllPlugins();
@@ -129,20 +129,9 @@ class Installer {
 	 */
 	function preInstall() {
 		$this->log('pre-install');
-		if (!isset($this->dbconn)) {
-			// Connect to the database.
-			$conn = DBConnection::getInstance();
-			$this->dbconn = $conn->getDBConn();
-
-			if (!$conn->isConnected()) {
-				$this->setError(INSTALLER_ERROR_DB, $this->dbconn->errorMsg());
-				return false;
-			}
-		}
-
 		if (!isset($this->currentVersion)) {
 			// Retrieve the currently installed version
-			$versionDao = DAORegistry::getDAO('VersionDAO');
+			$versionDao = DAORegistry::getDAO('VersionDAO'); /* @var $versionDao VersionDAO */
 			$this->currentVersion = $versionDao->getCurrentVersion();
 		}
 
@@ -156,11 +145,10 @@ class Installer {
 
 		if (!isset($this->dataXMLParser)) {
 			$this->dataXMLParser = new DBDataXMLParser();
-			$this->dataXMLParser->setDBConn($this->dbconn);
 		}
 
 		$result = true;
-		HookRegistry::call('Installer::preInstall', array($this, &$result));
+		HookRegistry::call('Installer::preInstall', [$this, &$result]);
 
 		return $result;
 	}
@@ -228,12 +216,11 @@ class Installer {
 	function parseInstaller() {
 		// Read installation descriptor file
 		$this->log(sprintf('load: %s', $this->descriptor));
-		$xmlParser = new XMLParser();
+		$xmlParser = new PKPXMLParser();
 		$installPath = $this->isPlugin ? $this->descriptor : INSTALLER_DATA_DIR . DIRECTORY_SEPARATOR . $this->descriptor;
 		$installTree = $xmlParser->parse($installPath);
 		if (!$installTree) {
 			// Error reading installation file
-			$xmlParser->destroy();
 			$this->setError(INSTALLER_ERROR_GENERAL, 'installer.installFileError');
 			return false;
 		}
@@ -247,7 +234,6 @@ class Installer {
 
 		// Parse descriptor
 		$this->parseInstallNodes($installTree);
-		$xmlParser->destroy();
 
 		$result = $this->getErrorType() == 0;
 
@@ -279,7 +265,7 @@ class Installer {
 	 */
 	function updateVersion() {
 		if ($this->newVersion->compare($this->currentVersion) > 0) {
-			$versionDao = DAORegistry::getDAO('VersionDAO');
+			$versionDao = DAORegistry::getDAO('VersionDAO'); /* @var $versionDao VersionDAO */
 			if (!$versionDao->insertVersion($this->newVersion)) {
 				return false;
 			}
@@ -306,6 +292,7 @@ class Installer {
 				case 'schema':
 				case 'data':
 				case 'code':
+				case 'migration':
 				case 'note':
 					$this->addInstallAction($node);
 					break;
@@ -364,10 +351,18 @@ class Installer {
 				$fileName = $action['file'];
 				$this->log(sprintf('schema: %s', $action['file']));
 
-				require_once './lib/pkp/lib/adodb/adodb-xmlschema.inc.php';
-				$schemaXMLParser = new adoSchema($this->dbconn);
+				require_once('lib/pkp/lib/vendor/adodb/adodb-php/adodb.inc.php');
+				require_once('./lib/pkp/lib/vendor/adodb/adodb-php/adodb-xmlschema.inc.php');
+				$dbconn = ADONewConnection(Config::getVar('database', 'driver'));
+				$port = Config::getVar('database', 'port');
+				$dbconn->Connect(
+					Config::getVar('database', 'host') . ($port ? ':' . $port : ''),
+					Config::getVar('database', 'username'),
+					Config::getVar('database', 'password'),
+					Config::getVar('database', 'name')
+				);
+				$schemaXMLParser = new adoSchema($dbconn);
 				$dict = $schemaXMLParser->dict;
-				$dict->SetCharSet($this->dbconn->charSet);
 				$sql = $schemaXMLParser->parseSchema($fileName);
 				$schemaXMLParser->destroy();
 
@@ -383,8 +378,11 @@ class Installer {
 				$condition = isset($action['attr']['condition'])?$action['attr']['condition']:null;
 				$includeAction = true;
 				if ($condition) {
-					$funcName = create_function('$installer,$action', $condition);
-					$includeAction = $funcName($this, $action);
+					// Create a new scope to evaluate the condition
+					$evalFunction = function($installer, $action) use ($condition) {
+						return eval($condition);
+					};
+					$includeAction = $evalFunction($this, $action);
 				}
 				$this->log('data: ' . $action['file'] . ($includeAction?'':' (skipped)'));
 				if (!$includeAction) break;
@@ -396,12 +394,43 @@ class Installer {
 					return $this->executeSQL($sql);
 				}
 				break;
+			case 'migration':
+				assert(isset($action['attr']['class']));
+				$fullClassName = $action['attr']['class'];
+				import($fullClassName);
+				$shortClassName = substr($fullClassName, strrpos($fullClassName, '.')+1);
+				$this->log(sprintf('migration: %s', $shortClassName));
+				$migration = new $shortClassName();
+				try {
+					$migration->up();
+					$this->migrations[] = $migration;
+				} catch (Exception $e) {
+					// Log an error message
+					$this->setError(
+						INSTALLER_ERROR_DB,
+						Config::getVar('debug', 'show_stacktrace') ? (string) $e : $e->getMessage()
+					);
+
+					// Back out already-executed migrations.
+					while ($previousMigration = array_pop($this->migrations)) {
+						try {
+							$previousMigration->down();
+						} catch (PKP\install\DowngradeNotSupportedException $e) {
+							break;
+						}
+					}
+					return false;
+				}
+				return true;
 			case 'code':
 				$condition = isset($action['attr']['condition'])?$action['attr']['condition']:null;
 				$includeAction = true;
 				if ($condition) {
-					$funcName = create_function('$installer,$action', $condition);
-					$includeAction = $funcName($this, $action);
+					// Create a new scope to evaluate the condition
+					$evalFunction = function($installer, $action) use ($condition) {
+						return eval($condition);
+					};
+					$includeAction = $evalFunction($this, $action);
 				}
 				$this->log(sprintf('code: %s %s::%s' . ($includeAction?'':' (skipped)'), isset($action['file']) ? $action['file'] : 'Installer', isset($action['attr']['class']) ? $action['attr']['class'] : 'Installer', $action['attr']['function']));
 				if (!$includeAction) return true; // Condition not met; skip the action.
@@ -437,9 +466,10 @@ class Installer {
 				}
 			}
 		} else {
-			$this->dbconn->execute($sql);
-			if ($this->dbconn->errorNo() != 0) {
-				$this->setError(INSTALLER_ERROR_DB, $this->dbconn->errorMsg());
+			try {
+				Capsule::affectingStatement($sql);
+			} catch (Exception $e) {
+				$this->setError(INSTALLER_ERROR_DB, $e->getMessage());
 				return false;
 			}
 		}
@@ -612,11 +642,16 @@ class Installer {
 	 * 		'locales' => 'en_US,fr_CA,...'
 	 */
 	function installEmailTemplate($installer, $attr) {
-		$emailTemplateDao = DAORegistry::getDAO('EmailTemplateDAO');
-		$emailTemplateDao->installEmailTemplates($emailTemplateDao->getMainEmailTemplatesFilename(), false, $attr['key']);
-		foreach (explode(',', $attr['locales']) as $locale) {
-			$emailTemplateDao->installEmailTemplateData($emailTemplateDao->getMainEmailTemplateDataFilename($locale), false, $attr['key']);
+		$locales = explode(',', $attr['locales']);
+		foreach ($locales as $locale) AppLocale::requireComponents(LOCALE_COMPONENT_APP_EMAIL, $locale);
+		$emailTemplateDao = DAORegistry::getDAO('EmailTemplateDAO'); /* @var $emailTemplateDao EmailTemplateDAO */
+		// FIXME pkp/pkp-lib#6284 Remove after drop of support for upgrades from 3.2.0
+		if (!Capsule::schema()->hasColumn('email_templates_default', 'stage_id')) {
+			Capsule::schema()->table('email_templates_default', function (Blueprint $table) {
+				$table->bigInteger('stage_id')->nullable();
+			});
 		}
+		$emailTemplateDao->installEmailTemplates($emailTemplateDao->getMainEmailTemplatesFilename(), $locales, false, $attr['key']);
 		return true;
 	}
 
@@ -629,14 +664,11 @@ class Installer {
 		static $filterHelper = false;
 
 		// Parse the filter configuration.
-		$xmlParser = new XMLParser();
+		$xmlParser = new PKPXMLParser();
 		$tree = $xmlParser->parse($filterConfigFile);
 
 		// Validate the filter configuration.
-		if (!$tree) {
-			$xmlParser->destroy();
-			return false;
-		}
+		if (!$tree) return false;
 
 		// Get the filter helper.
 		if ($filterHelper === false) {
@@ -658,8 +690,6 @@ class Installer {
 			}
 		}
 
-		// Get rid of the parser.
-		$xmlParser->destroy();
 		return true;
 	}
 
@@ -671,21 +701,12 @@ class Installer {
 	 * @return boolean
 	 */
 	function columnExists($tableName, $columnName) {
-		$siteDao = DAORegistry::getDAO('SiteDAO');
-		$dataSource = $siteDao->getDataSource();
-		$dict = NewDataDictionary($dataSource);
-
+		$schema = Capsule::connection()->getDoctrineSchemaManager();
 		// Make sure the table exists
-		$tables = $dict->MetaTables('TABLES', false);
+		$tables = $schema->listTableNames();
 		if (!in_array($tableName, $tables)) return false;
 
-		// Check to see whether it contains the specified column.
-		// Oddly, MetaColumnNames doesn't appear to be available.
-		$columns = $dict->MetaColumns($tableName);
-		foreach ($columns as $column) {
-			if ($column->name == $columnName) return true;
-		}
-		return false;
+		return Capsule::schema()->hasColumn($tableName, $columnName);
 	}
 
 	/**
@@ -695,12 +716,7 @@ class Installer {
 	 * @return boolean
 	 */
 	function tableExists($tableName) {
-		$siteDao = DAORegistry::getDAO('SiteDAO');
-		$dataSource = $siteDao->getDataSource();
-		$dict = NewDataDictionary($dataSource);
-
-		// Check whether the table exists.
-		$tables = $dict->MetaTables('TABLES', false);
+		$tables = Capsule::connection()->getDoctrineSchemaManager()->listTableNames();
 		return in_array($tableName, $tables);
 	}
 
@@ -710,14 +726,14 @@ class Installer {
 	 * @return boolean
 	 */
 	function addPluginVersions() {
-		$versionDao = DAORegistry::getDAO('VersionDAO');
+		$versionDao = DAORegistry::getDAO('VersionDAO'); /* @var $versionDao VersionDAO */
 		import('lib.pkp.classes.site.VersionCheck');
 		$fileManager = new FileManager();
 		$categories = PluginRegistry::getCategories();
 		foreach ($categories as $category) {
 			PluginRegistry::loadCategory($category);
 			$plugins = PluginRegistry::getPlugins($category);
-			if (is_array($plugins)) {
+			if (!empty($plugins)) {
 				foreach ($plugins as $plugin) {
 					$versionFile = $plugin->getPluginPath() . '/version.xml';
 
@@ -754,6 +770,276 @@ class Installer {
 		$installer->setError(INSTALLER_ERROR_GENERAL, $attr['message']);
 		return false;
 	}
-}
 
-?>
+	/**
+	 * For 3.1.0 upgrade.  DefaultMenus Defaults
+	 * @return boolean Success/failure
+	 */
+	function installDefaultNavigationMenus() {
+		$contextDao = Application::getContextDAO();
+		$navigationMenuDao = DAORegistry::getDAO('NavigationMenuDAO'); /* @var $navigationMenuDao NavigationMenuDAO */
+
+		$contexts = $contextDao->getAll();
+		while ($context = $contexts->next()) {
+			$navigationMenuDao->installSettings($context->getId(), 'registry/navigationMenus.xml');
+		}
+
+		$navigationMenuDao->installSettings(CONTEXT_ID_NONE, 'registry/navigationMenus.xml');
+
+		return true;
+	}
+
+	/**
+	 * Check that the environment meets minimum PHP requirements.
+	 * @return boolean Success/failure
+	 */
+	function checkPhpVersion() {
+		if (version_compare(PHP_REQUIRED_VERSION, PHP_VERSION) != 1) return true;
+
+		$this->setError(INSTALLER_ERROR_GENERAL, 'installer.unsupportedPhpError');
+		return false;
+	}
+
+	/*
+	 * Migrate site locale settings to a serialized array in the database
+	 */
+	function migrateSiteLocales() {
+		$siteDao = DAORegistry::getDAO('SiteDAO'); /* @var $siteDao SiteDAO */
+
+		$result = $siteDao->retrieve('SELECT installed_locales, supported_locales FROM site');
+
+		$set = $params = [];
+		$row = (array) $result->current();
+		$type = 'array';
+		foreach ($row as $column => $value) {
+			if (!empty($value)) {
+				$set[] = $column . ' = ?';
+				$params[] = $siteDao->convertToDB(explode(':', $value), $type);
+			}
+		}
+		$siteDao->update('UPDATE site SET ' . join(',', $set), $params);
+
+		return true;
+	}
+
+	/**
+	 * Migrate active sidebar blocks from plugin_settings to journal_settings
+	 *
+	 * @return boolean
+	 */
+	function migrateSidebarBlocks() {
+
+		$siteDao = DAORegistry::getDAO('SiteDAO'); /* @var $siteDao SiteDAO */
+		$site = $siteDao->getSite();
+
+		$plugins = PluginRegistry::loadCategory('blocks');
+		if (empty($plugins)) {
+			return true;
+		}
+
+		// Sanitize plugin names for use in sql IN().
+		$sanitizedPluginNames = array_map(function($name) {
+			return "'" . preg_replace("/[^A-Za-z0-9]/", '', $name) . "'";
+		}, array_keys($plugins));
+
+		$pluginSettingsDao = DAORegistry::getDAO('PluginSettingsDAO'); /* @var $pluginSettingsDao PluginSettingsDAO */
+		$result = $pluginSettingsDao->retrieve(
+			'SELECT plugin_name, context_id, setting_value FROM plugin_settings WHERE plugin_name IN (' . join(',', $sanitizedPluginNames) . ') AND setting_name=\'context\';'
+		);
+
+		$sidebarSettings = [];
+		foreach ($result as $row) {
+			if ($row->setting_value != 1) continue; // BLOCK_CONTEXT_SIDEBAR
+
+			$seq = $pluginSettingsDao->getSetting($row->context_id, $row->plugin_name, 'seq');
+			if (!isset($sidebarSettings[$row->context_id])) {
+				$sidebarSettings[$row->context_id] = [];
+			}
+			$sidebarSettings[$row->context_id][(int) $seq] = $row->plugin_name;
+		}
+
+		foreach ($sidebarSettings as $contextId => $contextSetting) {
+			// Order by sequence
+			ksort($contextSetting);
+			$contextSetting = array_values($contextSetting);
+			if ($contextId) {
+				$contextDao = Application::getContextDAO();
+				$context = $contextDao->getById($contextId);
+				$context->setData('sidebar', $contextSetting);
+				$contextDao->updateObject($context);
+			} else {
+				$siteDao = DAORegistry::getDAO('SiteDAO'); /* @var $siteDao SiteDAO */
+				$site = $siteDao->getSite();
+				$site->setData('sidebar', $contextSetting);
+				$siteDao->updateObject($site);
+			}
+		}
+
+		$pluginSettingsDao->update('DELETE FROM plugin_settings WHERE plugin_name IN (' . join(',', $sanitizedPluginNames ) . ') AND (setting_name=\'context\' OR setting_name=\'seq\');');
+
+		return true;
+	}
+
+	/**
+	 * Migrate the metadata settings in the database to use a single row with one
+	 * of the new constants
+	 */
+	function migrateMetadataSettings() {
+		$contextDao = Application::getContextDao();
+
+		$metadataSettings = [
+			'coverage',
+			'languages',
+			'rights',
+			'source',
+			'subjects',
+			'type',
+			'disciplines',
+			'keywords',
+			'agencies',
+			'citations',
+		];
+
+		$result = $contextDao->retrieve('SELECT ' . $contextDao->primaryKeyColumn . ' from ' . $contextDao->tableName);
+		$contextIds = [];
+		foreach ($result as $row) {
+			$row = (array) $row;
+			$contextIds[] = $row[$contextDao->primaryKeyColumn];
+		}
+
+		foreach ($metadataSettings as $metadataSetting) {
+			foreach ($contextIds as $contextId) {
+				$result = $contextDao->retrieve('
+					SELECT * FROM ' . $contextDao->settingsTableName . ' WHERE
+						' . $contextDao->primaryKeyColumn . ' = ?
+						AND (
+							setting_name = ?
+							OR setting_name = ?
+							OR setting_name = ?
+						)
+					',
+					[
+						$contextId,
+						$metadataSetting . 'EnabledWorkflow',
+						$metadataSetting . 'EnabledSubmission',
+						$metadataSetting . 'Required',
+					]
+				);
+				$value = METADATA_DISABLE;
+				foreach ($result as $row) {
+					if ($row->setting_name === $metadataSetting . 'Required' && $row->setting_value) {
+						$value = METADATA_REQUIRE;
+					} elseif ($row->setting_name === $metadataSetting . 'EnabledSubmission' && $row->setting_value && $value !== METADATA_REQUIRE) {
+						$value = METADATA_REQUEST;
+					} elseif ($row->setting_name === $metadataSetting . 'EnabledWorkflow' && $row->setting_value && $value !== METADATA_REQUEST && $value !== METADATA_REQUIRE) {
+						$value = METADATA_ENABLE;
+					}
+				}
+
+				if ($value !== METADATA_DISABLE) {
+					$contextDao->update('
+						INSERT INTO ' . $contextDao->settingsTableName . ' (
+							' . $contextDao->primaryKeyColumn . ',
+							locale,
+							setting_name,
+							setting_value
+						) VALUES (?, ?, ?, ?)',
+						[
+							$contextId,
+							'',
+							$metadataSetting,
+							$value,
+						]
+					);
+				}
+
+				$contextDao->update('
+					DELETE FROM ' . $contextDao->settingsTableName . ' WHERE
+						' . $contextDao->primaryKeyColumn . ' = ?
+						AND (
+							setting_name = ?
+							OR setting_name = ?
+							OR setting_name = ?
+						)
+					',
+					[
+						$contextId,
+						$metadataSetting . 'EnabledWorkflow',
+						$metadataSetting . 'EnabledSubmission',
+						$metadataSetting . 'Required',
+					]
+				);
+			}
+		}
+
+		return true;
+	}
+
+	/**
+	 * Set the notification settings for journal managers and subeditors so
+	 * that they are opted out of the monthly stats email.
+	 */
+	public function setStatsEmailSettings() {
+		import('lib.pkp.classes.notification.PKPNotification'); // NOTIFICATION_TYPE_EDITORIAL_REPORT
+		$roleIds = [ROLE_ID_MANAGER, ROLE_ID_SUB_EDITOR];
+
+		$userGroupDao = DAORegistry::getDAO('UserGroupDAO'); /* @var $userGroupDao UserGroupDAO */
+		$notificationSubscriptionSettingsDao = DAORegistry::getDAO('NotificationSubscriptionSettingsDAO'); /* @var $notificationSubscriptionSettingsDao NotificationSubscriptionSettingsDAO */
+		for ($contexts = Application::get()->getContextDAO()->getAll(true); $context = $contexts->next(); ) {
+			foreach ($roleIds as $roleId) {
+				for ($userGroups = $userGroupDao->getByRoleId($context->getId(), $roleId); $userGroup = $userGroups->next(); ) {
+					for ($users = $userGroupDao->getUsersById($userGroup->getId(), $context->getId()); $user = $users->next(); ) {
+						$notificationSubscriptionSettingsDao->update(
+							'INSERT INTO notification_subscription_settings
+								(setting_name, setting_value, user_id, context, setting_type)
+								VALUES
+								(?, ?, ?, ?, ?)',
+							array(
+								'blocked_emailed_notification',
+								NOTIFICATION_TYPE_EDITORIAL_REPORT,
+								$user->getId(),
+								$context->getId(),
+								'int'
+							)
+						);
+					}
+				}
+			}
+		}
+
+		return true;
+	}
+
+	/**
+	 * Fix library files, which were mistakenly named server-side using source filenames.
+	 * See https://github.com/pkp/pkp-lib/issues/5471
+	 * @return boolean
+	 */
+	public function fixLibraryFiles() {
+		import('classes.file.LibraryFileManager');
+		// Fetch all library files (no method currently in LibraryFileDAO for this)
+		$libraryFileDao = DAORegistry::getDAO('LibraryFileDAO'); /* @var $libraryFileDao LibraryFileDAO */
+		$result = $libraryFileDao->retrieve('SELECT * FROM library_files');
+		$libraryFiles = new DAOResultFactory($result, $libraryFileDao, '_fromRow', array('id'));
+		$wrongFiles = array();
+		while ($libraryFile = $libraryFiles->next()) {
+			$libraryFileManager = new LibraryFileManager($libraryFile->getContextId());
+			$wrongFilePath = $libraryFileManager->getBasePath() .  $libraryFile->getOriginalFileName();
+			$rightFilePath = $libraryFile->getFilePath();
+
+			if (isset($wrongFiles[$wrongFilePath])) {
+				error_log('A potential collision was found between library files ' . $libraryFile->getId() . ' and ' . $wrongFiles[$wrongFilePath]->getId() . '. Please review the database entries and ensure that the associated files are correct.');
+			} else {
+				$wrongFiles[$wrongFilePath] = $libraryFile;
+			}
+
+			// For all files for which the "wrong" filename exists and the "right" filename doesn't,
+			// copy the "wrong" file over to the "right" one. This will leave the "wrong" file in
+			// place, and won't disambiguate cases for which files were clobbered.
+			if (file_exists($wrongFilePath) && !file_exists($rightFilePath)) {
+				$libraryFileManager->copyFile($wrongFilePath, $rightFilePath);
+			}
+		}
+		return true;
+	}
+}
