@@ -2,9 +2,9 @@
 /**
  * @file classes/linkAction/request/AjaxModal.inc.php
  *
- * Copyright (c) 2014-2016 Simon Fraser University Library
- * Copyright (c) 2000-2016 John Willinsky
- * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
+ * Copyright (c) 2014-2021 Simon Fraser University
+ * Copyright (c) 2000-2021 John Willinsky
+ * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @class AjaxModal
  * @ingroup linkAction_request
@@ -25,9 +25,14 @@ class AjaxModal extends Modal {
 	 * @param $title string (optional) The localized modal title.
 	 * @param $titleIcon string (optional) The icon to be used in the modal title bar.
 	 * @param $canClose boolean (optional) Whether the modal will have a close button.
+	 * @param $closeOnFormSuccessId string (optional) Close the modal when the
+	 *  form with this id fires a formSuccess event.
+	 * @param $closeCleanVueInstances array (optional) When the modal is closed
+	 *  destroy the registered vue instances with these ids
 	 */
-	function AjaxModal($url, $title = null, $titleIcon = null, $canClose = true) {
-		parent::Modal($title, $titleIcon, $canClose);
+	function __construct($url, $title = null, $titleIcon = null, $canClose = true,
+			$closeOnFormSuccessId = null, $closeCleanVueInstances = []) {
+		parent::__construct($title, $titleIcon, $canClose, $closeOnFormSuccessId, $closeCleanVueInstances);
 
 		$this->_url = $url;
 	}
@@ -52,10 +57,12 @@ class AjaxModal extends Modal {
 	 * @see LinkActionRequest::getLocalizedOptions()
 	 */
 	function getLocalizedOptions() {
-		return array_merge(parent::getLocalizedOptions(), array(
+		return array_merge(
+			parent::getLocalizedOptions(),
+			array(
 				'modalHandler' => '$.pkp.controllers.modal.AjaxModalHandler',
-				'url' => $this->getUrl()));
+				'url' => $this->getUrl(),
+			)
+		);
 	}
 }
-
-?>
