@@ -3,9 +3,9 @@
 /**
  * @file classes/payment/QueuedPaymentDAO.inc.php
  *
- * Copyright (c) 2014-2019 Simon Fraser University
- * Copyright (c) 2000-2019 John Willinsky
- * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
+ * Copyright (c) 2014-2021 Simon Fraser University
+ * Copyright (c) 2000-2021 John Willinsky
+ * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @class QueuedPaymentDAO
  * @ingroup payment
@@ -27,16 +27,14 @@ class QueuedPaymentDAO extends DAO {
 	function getById($queuedPaymentId) {
 		$result = $this->retrieve(
 			'SELECT * FROM queued_payments WHERE queued_payment_id = ?',
-			(int) $queuedPaymentId
+			[(int) $queuedPaymentId]
 		);
-
-		$queuedPayment = null;
-		if ($result->RecordCount() != 0) {
-			$queuedPayment = unserialize($result->fields['payment_data']);
-			$queuedPayment->setId($result->fields['queued_payment_id']);
+		if ($row = $result->current()) {
+			$queuedPayment = unserialize($row->payment_data);
+			$queuedPayment->setId($row->queued_payment_id);
+			return $queuedPayment;
 		}
-		$result->Close();
-		return $queuedPayment;
+		return null;
 	}
 
 	/**
@@ -53,9 +51,9 @@ class QueuedPaymentDAO extends DAO {
 				$this->datetimeToDB(Core::getCurrentDate()),
 				$this->datetimeToDB(Core::getCurrentDate()),
 				$this->datetimeToDB($expiryDate)),
-			array(
+			[
 				serialize($queuedPayment)
-			)
+			]
 		);
 
 		return $queuedPayment->setId($this->getInsertId());
@@ -74,10 +72,10 @@ class QueuedPaymentDAO extends DAO {
 					payment_data = ?
 				WHERE queued_payment_id = ?',
 				$this->datetimeToDB(Core::getCurrentDate())),
-			array(
+			[
 				serialize($queuedPayment),
 				(int) $queuedPaymentId
-			)
+			]
 		);
 	}
 
@@ -94,11 +92,11 @@ class QueuedPaymentDAO extends DAO {
 	 * @param $queuedPaymentId int
 	 */
 	function deleteById($queuedPaymentId) {
-		$notificationDao = DAORegistry::getDAO('NotificationDAO');
+		$notificationDao = DAORegistry::getDAO('NotificationDAO'); /* @var $notificationDao NotificationDAO */
 		$notificationDao->deleteByAssoc(ASSOC_TYPE_QUEUED_PAYMENT, $queuedPaymentId);
-		return $this->update(
+		$this->update(
 			'DELETE FROM queued_payments WHERE queued_payment_id = ?',
-			array((int) $queuedPaymentId)
+			[(int) $queuedPaymentId]
 		);
 	}
 
@@ -106,9 +104,7 @@ class QueuedPaymentDAO extends DAO {
 	 * Delete expired queued payments.
 	 */
 	function deleteExpired() {
-		return $this->update(
-			'DELETE FROM queued_payments WHERE expiry_date < now()'
-		);
+		$this->update('DELETE FROM queued_payments WHERE expiry_date < now()');
 	}
 }
 
