@@ -3,9 +3,9 @@
 /**
  * @file classes/security/UserGroupDAO.inc.php
  *
- * Copyright (c) 2014-2019 Simon Fraser University
- * Copyright (c) 2003-2019 John Willinsky
- * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
+ * Copyright (c) 2014-2021 Simon Fraser University
+ * Copyright (c) 2003-2021 John Willinsky
+ * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @class UserGroupDAO
  * @ingroup security
@@ -55,6 +55,7 @@ class UserGroupDAO extends DAO {
 		$userGroup->setDefault($row['is_default']);
 		$userGroup->setShowTitle($row['show_title']);
 		$userGroup->setPermitSelfRegistration($row['permit_self_registration']);
+		$userGroup->setPermitMetadataEdit($row['permit_metadata_edit']);
 
 		$this->getDataObjectSettings('user_group_settings', 'user_group_id', $row['user_group_id'], $userGroup);
 
@@ -71,16 +72,17 @@ class UserGroupDAO extends DAO {
 	function insertObject($userGroup) {
 		$this->update(
 			'INSERT INTO user_groups
-				(role_id, context_id, is_default, show_title, permit_self_registration)
+				(role_id, context_id, is_default, show_title, permit_self_registration, permit_metadata_edit)
 				VALUES
-				(?, ?, ?, ?, ?)',
-			array(
+				(?, ?, ?, ?, ?, ?)',
+			[
 				(int) $userGroup->getRoleId(),
 				(int) $userGroup->getContextId(),
 				$userGroup->getDefault()?1:0,
 				$userGroup->getShowTitle()?1:0,
 				$userGroup->getPermitSelfRegistration()?1:0,
-			)
+				$userGroup->getPermitMetadataEdit()?1:0,
+			]
 		);
 
 		$userGroup->setId($this->getInsertId());
@@ -99,16 +101,18 @@ class UserGroupDAO extends DAO {
 				context_id = ?,
 				is_default = ?,
 				show_title = ?,
-				permit_self_registration = ?
+				permit_self_registration = ?,
+				permit_metadata_edit = ?
 			WHERE	user_group_id = ?',
-			array(
+			[
 				(int) $userGroup->getRoleId(),
 				(int) $userGroup->getContextId(),
 				$userGroup->getDefault()?1:0,
 				$userGroup->getShowTitle()?1:0,
 				$userGroup->getPermitSelfRegistration()?1:0,
+				$userGroup->getPermitMetadataEdit()?1:0,
 				(int) $userGroup->getId(),
-			)
+			]
 		);
 
 		$this->updateLocaleFields($userGroup);
@@ -122,8 +126,8 @@ class UserGroupDAO extends DAO {
 	 */
 	function deleteById($contextId, $userGroupId) {
 		$this->userGroupAssignmentDao->deleteAssignmentsByUserGroupId($userGroupId);
-		$this->update('DELETE FROM user_group_settings WHERE user_group_id = ?', (int) $userGroupId);
-		$this->update('DELETE FROM user_groups WHERE user_group_id = ?', (int) $userGroupId);
+		$this->update('DELETE FROM user_group_settings WHERE user_group_id = ?', [(int) $userGroupId]);
+		$this->update('DELETE FROM user_groups WHERE user_group_id = ?', [(int) $userGroupId]);
 		$this->removeAllStagesFromGroup($contextId, $userGroupId);
 	}
 
@@ -142,16 +146,13 @@ class UserGroupDAO extends DAO {
 	 * @param $contextId int
 	 */
 	function deleteByContextId($contextId) {
-		$result = $this->retrieve('SELECT user_group_id FROM user_groups WHERE context_id = ?', (int) $contextId);
+		$result = $this->retrieve('SELECT user_group_id FROM user_groups WHERE context_id = ?', [(int) $contextId]);
 
-		for ($i=1; !$result->EOF; $i++) {
-			list($userGroupId) = $result->fields;
-
-			$this->update('DELETE FROM user_group_stage WHERE user_group_id = ?', (int) $userGroupId);
-			$this->update('DELETE FROM user_group_settings WHERE user_group_id = ?', (int) $userGroupId);
-			$this->update('DELETE FROM user_groups WHERE user_group_id = ?', (int) $userGroupId);
-
-			$result->MoveNext();
+		for ($i=1; $row = (array) $result->current(); $i++) {
+			$this->update('DELETE FROM user_group_stage WHERE user_group_id = ?', [(int) $row['user_group_id']]);
+			$this->update('DELETE FROM user_group_settings WHERE user_group_id = ?', [(int) $row['user_group_id']]);
+			$this->update('DELETE FROM user_groups WHERE user_group_id = ?', [(int) $row['user_group_id']]);
+			$result->next();
 		}
 	}
 
@@ -168,16 +169,14 @@ class UserGroupDAO extends DAO {
 	 * @return array
 	 */
 	function getLocaleFieldNames() {
-		return array('name', 'abbrev');
+		return ['name', 'abbrev'];
 	}
 
 	/**
 	 * @copydoc DAO::getAdditionalFieldNames()
 	 */
 	function getAdditionalFieldNames() {
-		return array_merge(parent::getAdditionalFieldNames(), array(
-			'recommendOnly',
-		));
+		return array_merge(parent::getAdditionalFieldNames(), ['recommendOnly']);
 	}
 
 	/**
@@ -185,9 +184,9 @@ class UserGroupDAO extends DAO {
 	 * @param $author object
 	 */
 	function updateLocaleFields($userGroup) {
-		$this->updateDataObjectSettings('user_group_settings', $userGroup, array(
+		$this->updateDataObjectSettings('user_group_settings', $userGroup, [
 			'user_group_id' => (int) $userGroup->getId()
-		));
+		]);
 	}
 
 	/**
@@ -196,7 +195,7 @@ class UserGroupDAO extends DAO {
 	 * @param $contextId int Optional context ID to use for validation
 	 */
 	function getById($userGroupId, $contextId = null) {
-		$params = array((int) $userGroupId);
+		$params = [(int) $userGroupId];
 		if ($contextId !== null) $params[] = (int) $contextId;
 		$result = $this->retrieve(
 			'SELECT	*
@@ -204,19 +203,19 @@ class UserGroupDAO extends DAO {
 			WHERE	user_group_id = ?' . ($contextId !== null?' AND context_id = ?':''),
 			$params
 		);
-
-		return $this->_returnFromRow($result->GetRowAssoc(false));
+		$row = (array) $result->current();
+		return $row?$this->_returnFromRow($row):null;
 	}
 
 	/**
 	 * Get a single default user group with a particular roleId
 	 * @param $contextId int Context ID
 	 * @param $roleId int ROLE_ID_...
+	 * @return UserGroup|false
 	 */
 	function getDefaultByRoleId($contextId, $roleId) {
 		$allDefaults = $this->getByRoleId($contextId, $roleId, true);
-		if ($allDefaults->eof()) return false;
-		return $allDefaults->next();
+		return $allDefaults->next() ?? false;
 	}
 
 	/**
@@ -228,15 +227,10 @@ class UserGroupDAO extends DAO {
 		$result = $this->retrieve(
 			'SELECT is_default FROM user_groups
 			WHERE user_group_id = ?',
-			(int) $userGroupId
+			[(int) $userGroupId]
 		);
-
-		$result = $result->GetArray();
-		if (isset($result[0]['is_default'])) {
-			return $result[0]['is_default'];
-		} else {
-			return false;
-		}
+		$row = $result->current();
+		return $row && $row->is_default;
 	}
 
 	/**
@@ -248,10 +242,10 @@ class UserGroupDAO extends DAO {
 	 * @return DAOResultFactory
 	 */
 	function getByRoleId($contextId, $roleId, $default = false, $dbResultRange = null) {
-		$params = array((int) $contextId, (int) $roleId);
+		$params = [(int) $contextId, (int) $roleId];
 		if ($default) $params[] = 1; // true
 		$result = $this->retrieveRange(
-			'SELECT	*
+			$sql = 'SELECT	*
 			FROM	user_groups
 			WHERE	context_id = ? AND
 				role_id = ?
@@ -261,7 +255,7 @@ class UserGroupDAO extends DAO {
 			$dbResultRange
 		);
 
-		return new DAOResultFactory($result, $this, '_returnFromRow');
+		return new DAOResultFactory($result, $this, '_returnFromRow', [], $sql, $params, $dbResultRange);
 	}
 
 	/**
@@ -270,7 +264,7 @@ class UserGroupDAO extends DAO {
 	 * @param $contextId int Context ID
 	 */
 	function getUserGroupIdsByRoleId($roleId, $contextId = null) {
-		$params = array((int) $roleId);
+		$params = [(int) $roleId];
 		if ($contextId) $params[] = (int) $contextId;
 
 		$result = $this->retrieve(
@@ -281,13 +275,10 @@ class UserGroupDAO extends DAO {
 			$params
 		);
 
-		$userGroupIds = array();
-		while (!$result->EOF) {
-			$userGroupIds[] = (int) $result->fields[0];
-			$result->MoveNext();
+		$userGroupIds = [];
+		foreach ($result as $row) {
+			$userGroupIds[] = (int) $row->user_group_id;
 		}
-
-		$result->Close();
 		return $userGroupIds;
 	}
 
@@ -300,20 +291,16 @@ class UserGroupDAO extends DAO {
 	 */
 	function userInGroup($userId, $userGroupId) {
 		$result = $this->retrieve(
-			'SELECT	count(*)
+			'SELECT	count(*) AS row_count
 			FROM	user_groups ug
 				JOIN user_user_groups uug ON ug.user_group_id = uug.user_group_id
 			WHERE
 				uug.user_id = ? AND
 				ug.user_group_id = ?',
-			array((int) $userId, (int) $userGroupId)
+			[(int) $userId, (int) $userGroupId]
 		);
-
-		// > 0 because user could belong to more than one user group with this role
-		$returner = isset($result->fields[0]) && $result->fields[0] > 0 ? true : false;
-
-		$result->Close();
-		return $returner;
+		$row = $result->current();
+		return $row ? (boolean) $row->row_count : false;
 	}
 
 	/**
@@ -323,22 +310,19 @@ class UserGroupDAO extends DAO {
 	 * @return boolean
 	 */
 	function userInAnyGroup($userId, $contextId = null) {
-		$params = array((int) $userId);
+		$params = [(int) $userId];
 		if ($contextId) $params[] = (int) $contextId;
 
 		$result = $this->retrieve(
-			'SELECT	count(*)
+			'SELECT	count(*) AS row_count
 			FROM	user_groups ug
 				JOIN user_user_groups uug ON ug.user_group_id = uug.user_group_id
 			WHERE	uug.user_id = ?
 				' . ($contextId?' AND ug.context_id = ?':''),
 			$params
 		);
-
-		$returner = isset($result->fields[0]) && $result->fields[0] > 0 ? true : false;
-
-		$result->Close();
-		return $returner;
+		$row = $result->current();
+		return $row ? (boolean) $row->row_count : false;
 	}
 
 	/**
@@ -347,8 +331,8 @@ class UserGroupDAO extends DAO {
 	 * @param $contextId int
 	 * @return DAOResultFactory
 	 */
-	function getByUserId($userId, $contextId = null){
-		$params = array((int) $userId);
+	function getByUserId($userId, $contextId = null) {
+		$params = [(int) $userId];
 		if ($contextId) $params[] = (int) $contextId;
 
 		$result = $this->retrieve(
@@ -371,20 +355,14 @@ class UserGroupDAO extends DAO {
 	 */
 	function contextHasGroup($contextId, $userGroupId) {
 		$result = $this->retrieve(
-			'SELECT count(*)
+			'SELECT count(*) AS row_count
 				FROM user_groups ug
 				WHERE ug.user_group_id = ?
 				AND ug.context_id = ?',
-			array (
-				(int) $userGroupId,
-				(int) $contextId
-			)
+			[(int) $userGroupId, (int) $contextId]
 		);
-
-		$returner = isset($result->fields[0]) && $result->fields[0] == 0 ? false : true;
-
-		$result->Close();
-		return $returner;
+		$row = (array) $result->current();
+		return $row && $row['row_count'] != 0;
 	}
 
 	/**
@@ -394,18 +372,18 @@ class UserGroupDAO extends DAO {
 	 * @return DAOResultFactory
 	 */
 	function getByContextId($contextId = null, $dbResultRange = null) {
-		$params = array();
+		$params = [];
 		if ($contextId) $params[] = (int) $contextId;
 
 		$result = $this->retrieveRange(
-			'SELECT ug.*
+			$sql = 'SELECT ug.*
 			FROM	user_groups ug' .
 				($contextId?' WHERE ug.context_id = ?':''),
 			$params,
 			$dbResultRange
 		);
 
-		return new DAOResultFactory($result, $this, '_returnFromRow');
+		return new DAOResultFactory($result, $this, '_returnFromRow', [], $sql, $params, $dbResultRange);
 	}
 
 	/**
@@ -414,23 +392,20 @@ class UserGroupDAO extends DAO {
 	 * @return int
 	 */
 	function getContextUsersCount($contextId, $userGroupId = null, $roleId = null) {
-		$params = array((int) $contextId);
+		$params = [(int) $contextId];
 		if ($userGroupId) $params[] = (int) $userGroupId;
 		if ($roleId) $params[] = (int) $roleId;
 		$result = $this->retrieve(
-			'SELECT	COUNT(DISTINCT(uug.user_id))
+			'SELECT	COUNT(DISTINCT(uug.user_id)) AS row_count
 			FROM	user_groups ug
 				JOIN user_user_groups uug ON ug.user_group_id = uug.user_group_id
-			WHERE	context_id = ?' .
+			WHERE	ug.context_id = ?' .
 				($userGroupId?' AND ug.user_group_id = ?':'') .
 				($roleId?' AND ug.role_id = ?':''),
 			$params
 		);
-
-		$returner = $result->fields[0];
-
-		$result->Close();
-		return (int) $returner;
+		$row = (array) $result->current();
+		return $row?$row['row_count']:0;
 	}
 
 	/**
@@ -455,7 +430,7 @@ class UserGroupDAO extends DAO {
 	 * @return DAOResultFactory
 	 */
 	function getUsersNotInRole($roleId, $contextId = null, $search = null, $rangeInfo = null) {
-		$params = isset($search) ? array(IDENTITY_SETTING_GIVENNAME, IDENTITY_SETTING_FAMILYNAME) : array();
+		$params = isset($search) ? [IDENTITY_SETTING_GIVENNAME, IDENTITY_SETTING_FAMILYNAME] : [];
 		$params[] = (int) $roleId;
 		if ($contextId) $params[] = (int) $contextId;
 		if(isset($search)) $params = array_merge($params, array_pad(array(), 4, '%' . $search . '%'));
@@ -493,13 +468,17 @@ class UserGroupDAO extends DAO {
 	 * @return DAOResultFactory
 	 */
 	function getUsersById($userGroupId = null, $contextId = null, $searchType = null, $search = null, $searchMatch = null, $dbResultRange = null) {
-		$params = $this->userDao->getFetchParameters();
-		$params = array_merge($params, array(IDENTITY_SETTING_GIVENNAME, IDENTITY_SETTING_FAMILYNAME));
+		$params = array_merge(
+			$this->userDao->getFetchParameters(),
+			[IDENTITY_SETTING_GIVENNAME, IDENTITY_SETTING_FAMILYNAME]
+		);
 		if ($contextId) $params[] = (int) $contextId;
 		if ($userGroupId) $params[] = (int) $userGroupId;
 
-		$sql =
-			'SELECT DISTINCT u.*,
+
+		// Get the result set
+		$result = $this->retrieveRange(
+			$sql = 'SELECT DISTINCT u.*,
 				' . $this->userDao->getFetchColumns() .'
 			FROM	users AS u
 				LEFT JOIN user_settings us ON (us.user_id = u.user_id AND us.setting_name = \'affiliation\')
@@ -514,15 +493,12 @@ class UserGroupDAO extends DAO {
 			WHERE	1=1 ' .
 				($contextId?'AND ug.context_id = ? ':'') .
 				($userGroupId?'AND ug.user_group_id = ? ':'') .
-				$this->_getSearchSql($searchType, $search, $searchMatch, $params);
-
-		$result = $this->retrieveRange(
-			$sql,
+				$this->_getSearchSql($searchType, $search, $searchMatch, $params),
 			$params,
 			$dbResultRange
 		);
 
-		return new DAOResultFactory($result, $this->userDao, '_returnUserFromRowWithData');
+		return new DAOResultFactory($result, $this->userDao, '_returnUserFromRowWithData', [], $sql, $params, $dbResultRange);
 	}
 
 	//
@@ -601,7 +577,7 @@ class UserGroupDAO extends DAO {
 	function assignGroupToStage($contextId, $userGroupId, $stageId) {
 		$this->update(
 			'INSERT INTO user_group_stage (context_id, user_group_id, stage_id) VALUES (?, ?, ?)',
-			array((int) $contextId, (int) $userGroupId, (int) $stageId)
+			[(int) $contextId, (int) $userGroupId, (int) $stageId]
 		);
 	}
 
@@ -614,7 +590,7 @@ class UserGroupDAO extends DAO {
 	function removeGroupFromStage($contextId, $userGroupId, $stageId) {
 		$this->update(
 			'DELETE FROM user_group_stage WHERE context_id = ? AND user_group_id = ? AND stage_id = ?',
-			array((int) $contextId, (int) $userGroupId, (int) $stageId)
+			[(int) $contextId, (int) $userGroupId, (int) $stageId]
 		);
 	}
 
@@ -630,31 +606,29 @@ class UserGroupDAO extends DAO {
 	 * @param $isLocalized boolean
 	 */
 	function updateSetting($userGroupId, $name, $value, $type = null, $isLocalized = false) {
-		$keyFields = array('setting_name', 'locale', 'user_group_id');
+		$keyFields = ['setting_name', 'locale', 'user_group_id'];
 
 		if (!$isLocalized) {
 			$value = $this->convertToDB($value, $type);
 			$this->replace('user_group_settings',
-				array(
+				[
 					'user_group_id' => (int) $userGroupId,
 					'setting_name' => $name,
 					'setting_value' => $value,
 					'setting_type' => $type,
 					'locale' => ''
-				),
+				],
 				$keyFields
 			);
 		} else {
 			if (is_array($value)) foreach ($value as $locale => $localeValue) {
-				$this->update('DELETE FROM user_group_settings WHERE user_group_id = ? AND setting_name = ? AND locale = ?', array((int) $userGroupId, $name, $locale));
+				$this->update('DELETE FROM user_group_settings WHERE user_group_id = ? AND setting_name = ? AND locale = ?', [(int) $userGroupId, $name, $locale]);
 				if (empty($localeValue)) continue;
 				$type = null;
 				$this->update('INSERT INTO user_group_settings
 					(user_group_id, setting_name, setting_value, setting_type, locale)
 					VALUES (?, ?, ?, ?, ?)',
-					array(
-						$userGroupId, $name, $this->convertToDB($localeValue, $type), $type, $locale
-					)
+					[$userGroupId, $name, $this->convertToDB($localeValue, $type), $type, $locale]
 				);
 			}
 		}
@@ -669,7 +643,7 @@ class UserGroupDAO extends DAO {
 	 * @return mixed
 	 */
 	function getSetting($userGroupId, $name, $locale = null) {
-		$params = array((int) $userGroupId, $name);
+		$params = [(int) $userGroupId, $name];
 		if ($locale) $params[] = $locale;
 		$result = $this->retrieve(
 			'SELECT	setting_name, setting_value, setting_type, locale
@@ -680,20 +654,15 @@ class UserGroupDAO extends DAO {
 			$params
 		);
 
-		$recordCount = $result->RecordCount();
 		$returner = false;
-		if ($recordCount == 1) {
-			$row = $result->getRowAssoc(false);
-			$returner = $this->convertFromDB($row['setting_value'], $row['setting_type']);
-		} elseif ($recordCount > 1) {
-			$returner = array();
-			while (!$result->EOF) {
-				$returner[$row['locale']] = $this->convertFromDB($row['setting_value'], $row['setting_type']);
-				$result->MoveNext();
-			}
-			$result->Close();
+		if ($row = $result->current()) {
+			return $this->convertFromDB($row->setting_value, $row->setting_type);
 		}
-		return $returner;
+		$returner = [];
+		foreach ($result as $row) {
+			$returner[$row->locale] = $this->convertFromDB($row->setting_value, $row->setting_type);
+		}
+		return count($returner) ? $returner : false;
 	}
 
 	//
@@ -707,31 +676,35 @@ class UserGroupDAO extends DAO {
 	 * @return boolean true === success
 	 */
 	function installSettings($contextId, $filename) {
-		$xmlParser = new XMLParser();
+		$xmlParser = new PKPXMLParser();
 		$tree = $xmlParser->parse($filename);
 
-		$siteDao = DAORegistry::getDAO('SiteDAO');
+		$siteDao = DAORegistry::getDAO('SiteDAO'); /* @var $siteDao SiteDAO */
 		$site = $siteDao->getSite();
 		$installedLocales = $site->getInstalledLocales();
 
-		if (!$tree) {
-			$xmlParser->destroy();
-			return false;
-		}
+		if (!$tree) return false;
 
 		foreach ($tree->getChildren() as $setting) {
 			$roleId = hexdec($setting->getAttribute('roleId'));
 			$nameKey = $setting->getAttribute('name');
 			$abbrevKey = $setting->getAttribute('abbrev');
 			$permitSelfRegistration = $setting->getAttribute('permitSelfRegistration');
+			$permitMetadataEdit = $setting->getAttribute('permitMetadataEdit');
+
+			// If has manager role then permitMetadataEdit can't be overriden
+			if (in_array($roleId, array(ROLE_ID_MANAGER))) {
+				$permitMetadataEdit = $setting->getAttribute('permitMetadataEdit');
+			}
+
 			$defaultStages = explode(',', $setting->getAttribute('stages'));
-			$userGroup = $this->newDataObject();
 
 			// create a role associated with this user group
 			$userGroup = $this->newDataObject();
 			$userGroup->setRoleId($roleId);
 			$userGroup->setContextId($contextId);
 			$userGroup->setPermitSelfRegistration($permitSelfRegistration);
+			$userGroup->setPermitMetadataEdit($permitMetadataEdit);
 			$userGroup->setDefault(true);
 
 			// insert the group into the DB
@@ -771,7 +744,7 @@ class UserGroupDAO extends DAO {
 			$nameKey = $this->getSetting($userGroup->getId(), 'nameLocaleKey');
 			$this->updateSetting($userGroup->getId(),
 				'name',
-				array($locale => __($nameKey, null, $locale)),
+				[$locale => __($nameKey, null, $locale)],
 				'string',
 				$locale,
 				true
@@ -780,7 +753,7 @@ class UserGroupDAO extends DAO {
 			$abbrevKey = $this->getSetting($userGroup->getId(), 'abbrevLocaleKey');
 			$this->updateSetting($userGroup->getId(),
 				'abbrev',
-				array($locale => __($abbrevKey, null, $locale)),
+				[$locale => __($abbrevKey, null, $locale)],
 				'string',
 				$locale,
 				true
@@ -793,7 +766,7 @@ class UserGroupDAO extends DAO {
 	 * @param $locale
 	 */
 	function deleteSettingsByLocale($locale) {
-		return $this->update('DELETE FROM user_group_settings WHERE locale = ?', $locale);
+		return $this->update('DELETE FROM user_group_settings WHERE locale = ?', [$locale]);
 	}
 
 	/**
@@ -805,13 +778,13 @@ class UserGroupDAO extends DAO {
 	 * @return string SQL search snippet
 	 */
 	function _getSearchSql($searchType, $search, $searchMatch, &$params) {
-		$searchTypeMap = array(
+		$searchTypeMap = [
 			IDENTITY_SETTING_GIVENNAME => 'usgs.setting_value',
 			IDENTITY_SETTING_FAMILYNAME => 'usfs.setting_value',
 			USER_FIELD_USERNAME => 'u.username',
 			USER_FIELD_EMAIL => 'u.email',
 			USER_FIELD_AFFILIATION => 'us.setting_value',
-		);
+		];
 
 		$searchSql = '';
 
@@ -876,11 +849,11 @@ class UserGroupDAO extends DAO {
 	 * @return DAOResultFactory
 	 */
 	function getUserGroupsByStage($contextId, $stageId, $roleId = null, $dbResultRange = null) {
-		$params = array((int) $contextId, (int) $stageId);
+		$params = [(int) $contextId, (int) $stageId];
 		if ($roleId) $params[] = (int) $roleId;
 		return new DAOResultFactory(
 			$this->retrieveRange(
-				'SELECT	ug.*
+				$sql = 'SELECT	ug.*
 				FROM	user_groups ug
 					JOIN user_group_stage ugs ON (ug.user_group_id = ugs.user_group_id AND ug.context_id = ugs.context_id)
 				WHERE	ugs.context_id = ? AND
@@ -891,7 +864,9 @@ class UserGroupDAO extends DAO {
 				$dbResultRange
 			),
 			$this,
-			'_returnFromRow'
+			'_returnFromRow',
+			[],
+			$sql, $params, $dbResultRange
 		);
 	}
 
@@ -907,16 +882,13 @@ class UserGroupDAO extends DAO {
 			FROM	user_group_stage
 			WHERE	context_id = ? AND
 				user_group_id = ?',
-			array((int) $contextId, (int) $userGroupId)
+			[(int) $contextId, (int) $userGroupId]
 		);
 
-		$returner = array();
-		while (!$result->EOF) {
-			$stageId = $result->Fields('stage_id');
-			$returner[$stageId] = WorkflowStageDAO::getTranslationKeyFromId($stageId);
-			$result->MoveNext();
+		$returner = [];
+		foreach ($result as $row) {
+			$returner[$row->stage_id] = WorkflowStageDAO::getTranslationKeyFromId($row->stage_id);
 		}
-
 		return $returner;
 	}
 
@@ -928,17 +900,14 @@ class UserGroupDAO extends DAO {
 	 */
 	function userGroupAssignedToStage($userGroupId, $stageId) {
 		$result = $this->retrieve(
-			'SELECT COUNT(*)
+			'SELECT COUNT(*) AS row_count
 			FROM	user_group_stage
 			WHERE	user_group_id = ? AND
 			stage_id = ?',
-			array((int) $userGroupId, (int) $stageId)
+			[(int) $userGroupId, (int) $stageId]
 		);
-
-		$returner = isset($result->fields[0]) && $result->fields[0] > 0 ? true : false;
-
-		$result->Close();
-		return $returner;
+		$row = $result->current();
+		return $row ? (boolean) $row->row_count : false;
 	}
 
 	/**
@@ -950,20 +919,17 @@ class UserGroupDAO extends DAO {
 	 */
 	function userAssignmentExists($contextId, $userId, $stageId) {
 		$result = $this->retrieve(
-			'SELECT	COUNT(*)
+			'SELECT	COUNT(*) AS row_count
 			FROM	user_group_stage ugs,
 			user_user_groups uug
 			WHERE	ugs.user_group_id = uug.user_group_id AND
 			ugs.context_id = ? AND
 			uug.user_id = ? AND
 			ugs.stage_id = ?',
-			array((int) $contextId, (int) $userId, (int) $stageId)
+			[(int) $contextId, (int) $userId, (int) $stageId]
 		);
-
-		$returner = isset($result->fields[0]) && $result->fields[0] > 0 ? true : false;
-
-		$result->Close();
-		return $returner;
+		$row = $result->current();
+		return $row ? (boolean) $row->row_count : false;
 	}
 
 	/**
@@ -973,11 +939,11 @@ class UserGroupDAO extends DAO {
 	 * @return array
 	 */
 	function getRecommendOnlyGroupIds($contextId, $roleId = null) {
-		$params = array((int) $contextId);
+		$params = [(int) $contextId];
 		if ($roleId) $params[] = (int) $roleId;
 
 		$result = $this->retrieve(
-			'SELECT	ug.user_group_id
+			'SELECT	ug.user_group_id AS user_group_id
 			FROM user_groups ug
 			JOIN user_group_settings ugs ON (ugs.user_group_id = ug.user_group_id AND ugs.setting_name = \'recommendOnly\' AND ugs.setting_value = \'1\')
 			WHERE ug.context_id = ?
@@ -985,16 +951,46 @@ class UserGroupDAO extends DAO {
 			$params
 		);
 
-		$userGroupIds = array();
-		while (!$result->EOF) {
-			$userGroupIds[] = (int) $result->fields[0];
-			$result->MoveNext();
+		$userGroupIds = [];
+		foreach ($result as $row) {
+			$userGroupIds[] = (int) $row->user_group_id;
 		}
-
-		$result->Close();
 		return $userGroupIds;
 	}
 
+	/**
+	 * Get all user group IDs with permit_metadata_edit option enabled.
+	 * @param $contextId integer
+	 * @param $roleId integer (optional)
+	 * @return array
+	 */
+	function getPermitMetadataEditGroupIds($contextId, $roleId = null) {
+		$params = [(int) $contextId];
+		if ($roleId) $params[] = (int) $roleId;
+
+		$result = $this->retrieve(
+			'SELECT	ug.user_group_id AS user_group_id
+			FROM user_groups ug
+			WHERE permit_metadata_edit = 1 AND
+			ug.context_id = ?
+			' . ($roleId?' AND ug.role_id = ?':''),
+			$params
+		);
+
+		$userGroupIds = [];
+		foreach ($result as $row) {
+			$userGroupIds[] = (int) $row->user_group_id;
+		}
+		return $userGroupIds;
+	}
+
+	/**
+	 * Get a list of roles not able to change submissionMetadataEdit permission option.
+	 * @return array
+	 */
+	static function getNotChangeMetadataEditPermissionRoles() {
+		return [ROLE_ID_MANAGER];
+	}
 }
 
 
