@@ -3,9 +3,9 @@
 /**
  * @file controllers/api/file/linkAction/AddRevisionLinkAction.inc.php
  *
- * Copyright (c) 2014-2016 Simon Fraser University Library
- * Copyright (c) 2003-2016 John Willinsky
- * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
+ * Copyright (c) 2014-2021 Simon Fraser University
+ * Copyright (c) 2003-2021 John Willinsky
+ * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @class AddRevisionLinkAction
  * @ingroup controllers_api_file_linkAction
@@ -23,9 +23,8 @@ class AddRevisionLinkAction extends BaseAddFileLinkAction {
 	 * @param $reviewRound ReviewRound The review round to upload to.
 	 * @param $uploaderRoles array The ids of all roles allowed to upload
 	 *  in the context of this action.
-	 * @param $uploaderGroupIds The user group IDs of all uploaders
 	 */
-	function AddRevisionLinkAction($request, $reviewRound, $uploaderRoles, $uploaderGroupIds = null) {
+	function __construct($request, $reviewRound, $uploaderRoles) {
 		// Bring in the submission file constants.
 		import('lib.pkp.classes.submission.SubmissionFile');
 
@@ -38,12 +37,12 @@ class AddRevisionLinkAction extends BaseAddFileLinkAction {
 		);
 
 		// Call the parent class constructor.
-		parent::BaseAddFileLinkAction(
-			$request, $reviewRound->getSubmissionId(), $reviewRound->getStageId(), $uploaderRoles, $uploaderGroupIds, $actionArgs,
+		parent::__construct(
+			$request, $reviewRound->getSubmissionId(), $reviewRound->getStageId(), $uploaderRoles, $actionArgs,
 			__('submission.review.uploadRevisionToRound', array('round' => $reviewRound->getRound())),
 			__('submission.addFile')
 		);
 	}
 }
 
-?>
+
