@@ -3,9 +3,9 @@
 /**
  * @file controllers/grid/notifications/TaskNotificationsGridHandler.inc.php
  *
- * Copyright (c) 2014-2016 Simon Fraser University Library
- * Copyright (c) 2003-2016 John Willinsky
- * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
+ * Copyright (c) 2014-2021 Simon Fraser University
+ * Copyright (c) 2003-2021 John Willinsky
+ * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @class TaskNotificationsGridHandler
  * @ingroup controllers_grid_notifications
@@ -19,10 +19,13 @@ import('lib.pkp.controllers.grid.notifications.NotificationsGridHandler');
 class TaskNotificationsGridHandler extends NotificationsGridHandler {
 
 	/**
-	 * Constructor
+	 * @copydoc GridHandler::initialize()
 	 */
-	function TaskNotificationsGridHandler() {
-		parent::NotificationsGridHandler();
+	function initialize($request, $args = null) {
+		parent::initialize($request, $args);
+
+		// Basic grid configuration.
+		$this->setTitle('common.tasks');
 	}
 
 	/**
@@ -34,9 +37,15 @@ class TaskNotificationsGridHandler extends NotificationsGridHandler {
 
 		// Get all level task notifications.
 		$notificationDao = DAORegistry::getDAO('NotificationDAO'); /* @var $notificationDao NotificationDAO */
-		$notifications = $notificationDao->getByUserId($user->getId(), NOTIFICATION_LEVEL_TASK);
-		return $notifications->toAssociativeArray();
+		$notifications = $notificationDao->getByUserId($user->getId(), NOTIFICATION_LEVEL_TASK)->toArray();
+
+		// Checkbox selection requires the array keys match the notification id
+		$notificationsForRow = [];
+		foreach ($notifications as $notification) {
+			$notificationsForRow[$notification->getId()] = $notification;
+		}
+		return $notificationsForRow;
 	}
 }
 
-?>
+
