@@ -3,9 +3,9 @@
 /**
  * @file controllers/grid/users/stageParticipant/StageParticipantGridCategoryRow.inc.php
  *
- * Copyright (c) 2014-2016 Simon Fraser University Library
- * Copyright (c) 2000-2016 John Willinsky
- * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
+ * Copyright (c) 2014-2021 Simon Fraser University
+ * Copyright (c) 2000-2021 John Willinsky
+ * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @class StageParticipantGridCategoryRow
  * @ingroup controllers_grid_users_stageParticipant
@@ -28,10 +28,10 @@ class StageParticipantGridCategoryRow extends GridCategoryRow {
 	/**
 	 * Constructor
 	 */
-	function StageParticipantGridCategoryRow($submission, $stageId) {
+	function __construct($submission, $stageId) {
 		$this->_submission = $submission;
 		$this->_stageId = $stageId;
-		parent::GridCategoryRow();
+		parent::__construct();
 	}
 
 	//
@@ -65,4 +65,4 @@ class StageParticipantGridCategoryRow extends GridCategoryRow {
 	}
 }
 
-?>
+
