@@ -1,9 +1,9 @@
 /**
  * @file js/classes/linkAction/OpenWindowRequest.js
  *
- * Copyright (c) 2014-2016 Simon Fraser University Library
- * Copyright (c) 2000-2016 John Willinsky
- * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
+ * Copyright (c) 2014-2021 Simon Fraser University
+ * Copyright (c) 2000-2021 John Willinsky
+ * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @class OpenWindowRequest
  * @ingroup js_classes_linkAction
@@ -45,9 +45,8 @@
 		var options = this.getOptions();
 		window.open(options.url);
 
-		return /** @type {boolean} */ this.parent('activate', element, event);
+		return /** @type {boolean} */ (this.parent('activate', element, event));
 	};
 
 
-/** @param {jQuery} $ jQuery closure. */
 }(jQuery));
