@@ -4,9 +4,9 @@
 /**
  * @file js/controllers/wizard/WizardHandler.js
  *
- * Copyright (c) 2014-2019 Simon Fraser University
- * Copyright (c) 2000-2019 John Willinsky
- * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
+ * Copyright (c) 2014-2021 Simon Fraser University
+ * Copyright (c) 2000-2021 John Willinsky
+ * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @class WizardHandler
  * @ingroup js_controllers_wizard
@@ -539,7 +539,7 @@
 			handler = $.pkp.classes.Handler.getHandler($('#' + $form.attr('id')));
 			if (prompt) {
 				if (handler.formChangesTracked) {
-					if (!confirm($.pkp.locale.form_dataHasChanged)) {
+					if (!confirm(pkp.localeKeys['form.dataHasChanged'])) {
 						return true; // the user has clicked cancel, they wish to stay.
 					} else {
 						handler.unregisterForm();
@@ -583,7 +583,7 @@
 					// Attach the continue request handler.
 					bind('click',
 							this.callbackWrapper(this.continueRequest));
-			this.$continueButton_ = /** @type {jQueryObject} */ $continueButton;
+			this.$continueButton_ = /** @type {jQueryObject} */ ($continueButton);
 			this.$progressIndicator_ = $progressIndicator;
 
 			// Remember the button labels.
@@ -629,5 +629,4 @@
 	};
 
 
-/** @param {jQuery} $ jQuery closure. */
 }(jQuery));
