@@ -3,9 +3,9 @@
 /**
  * @file plugins/generic/usageEvent/PKPUsageEventPlugin.inc.php
  *
- * Copyright (c) 2013-2019 Simon Fraser University
- * Copyright (c) 2003-2019 John Willinsky
- * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
+ * Copyright (c) 2013-2021 Simon Fraser University
+ * Copyright (c) 2003-2021 John Willinsky
+ * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @class PKPUsageEventPlugin
  * @ingroup plugins_generic_usageEvent
@@ -84,6 +84,20 @@ abstract class PKPUsageEventPlugin extends GenericPlugin {
 		return true;
 	}
 
+	/**
+	 * @copydoc Plugin::getCanEnable()
+	 */
+	function getCanEnable() {
+		return false;
+	}
+
+	/**
+	 * @copydoc Plugin::getCanDisable()
+	 */
+	function getCanDisable() {
+		return false;
+	}
+
 
 	//
 	// Public methods.
@@ -154,7 +168,7 @@ abstract class PKPUsageEventPlugin extends GenericPlugin {
 			return null;
 		}
 
-		$application = Application::getApplication();
+		$application = Application::get();
 		$request = $application->getRequest();
 		$router = $request->getRouter(); /* @var $router PageRouter */
 		$templateMgr = $args[0]; /* @var $templateMgr TemplateManager */
@@ -179,12 +193,13 @@ abstract class PKPUsageEventPlugin extends GenericPlugin {
 		$htmlPageAssocTypes = $this->getHtmlPageAssocTypes();
 		if (in_array($assocType, $htmlPageAssocTypes)) {
 			// HTML pages with no file downloads.
-			$docSize = 0;
 			$mimeType = 'text/html';
+		} elseif (is_a($pubObject, 'IssueGalley')) {
+			$mimeType = $pubObject->getFileType();
 		} else {
 			// Files.
-			$docSize = (int)$pubObject->getFileSize();
-			$mimeType = $pubObject->getFileType();
+			$path = $pubObject->getData('path');
+			$mimeType = $pubObject->getData('mimetype');
 		}
 
 		$canonicalUrl = $router->url(
@@ -228,7 +243,7 @@ abstract class PKPUsageEventPlugin extends GenericPlugin {
 		// 2) Standardized public identifiers, e.g. DOI, URN, etc.
 		if ($this->isPubIdObjectType($pubObject)) {
 			$pubIdPlugins = PluginRegistry::loadCategory('pubIds', true, $context->getId());
-			if (is_array($pubIdPlugins)) {
+			if (!empty($pubIdPlugins)) {
 				foreach ($pubIdPlugins as $pubIdPlugin) {
 					if (!$pubIdPlugin->getEnabled()) continue;
 					$pubId = $pubObject->getStoredPubId($pubIdPlugin->getPubIdType());
@@ -298,7 +313,6 @@ abstract class PKPUsageEventPlugin extends GenericPlugin {
 		* %t: request time => $time
 		* %r: query => derived objects: $pubObject, $assocType, $canonicalUrl, $identifiers, $serviceUri, $classification
 		* %s: status => not supported (always 200 in our case)
-		* %b: response size => $docSize
 		*
 		* 2) other common parameters
 		* %O: bytes sent => not supported (cannot be reliably determined from within PHP)
@@ -315,7 +329,7 @@ abstract class PKPUsageEventPlugin extends GenericPlugin {
 		// Collect all information into an array.
 		$usageEvent = compact(
 			'time', 'pubObject', 'assocType', 'canonicalUrl', 'mimeType',
-			'identifiers', 'docSize', 'downloadSuccess', 'serviceUri',
+			'identifiers', 'downloadSuccess', 'serviceUri',
 			'ip', 'host', 'user', 'roles', 'userAgent', 'referrer',
 			'classification'
 		);
