@@ -1,12 +1,12 @@
 <?php
 
 /**
- * @file plugins/generic/googleAnalytics/OrcidProfileSettingsForm.inc.php
+ * @file OrcidProfileSettingsForm.inc.php
  *
  * Copyright (c) 2015-2019 University of Pittsburgh
- * Copyright (c) 2014-2019 Simon Fraser University
- * Copyright (c) 2003-2019 John Willinsky
- * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
+ * Copyright (c) 2014-2020 Simon Fraser University
+ * Copyright (c) 2003-2020 John Willinsky
+ * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @class OrcidProfileSettingsForm
  * @ingroup plugins_generic_orcidProfile
@@ -22,9 +22,11 @@ class OrcidProfileSettingsForm extends Form {
 	const CONFIG_VARS = array(
 		'orcidProfileAPIPath' => 'string',
 		'orcidClientId' => 'string',
-		'orcidClientSecret' => 'string',		
+		'orcidClientSecret' => 'string',
 		'sendMailToAuthorsOnPublication' => 'bool',
-		'logLevel' => 'string');
+		'logLevel' => 'string',
+		'isSandBox' => 'bool'
+	);
 	/** @var $contextId int */
 	var $contextId;
 
@@ -42,12 +44,32 @@ class OrcidProfileSettingsForm extends Form {
 
 		parent::__construct($plugin->getTemplateResource('settingsForm.tpl'));
 
-		if(!$this->plugin->isGloballyConfigured()) {
+		if (!$this->plugin->isGloballyConfigured()) {
 			$this->addCheck(new FormValidator($this, 'orcidProfileAPIPath', 'required',
 				'plugins.generic.orcidProfile.manager.settings.orcidAPIPathRequired'));
 		}
 		$this->addCheck(new FormValidatorPost($this));
 		$this->addCheck(new FormValidatorCSRF($this));
+		$this->addCheck(new FormValidatorCustom($this, 'orcidClientId', 'required', 'plugins.generic.orcidProfile.manager.settings.orcidClientId.error', function ($clientId) {
+			if (preg_match('/^APP-[\da-zA-Z]{16}|(\d{4}-){3,}\d{3}[\dX]/', $clientId) == 1) {
+				$this->plugin->setEnabled(true);
+				return true;
+			} else {
+				$this->plugin->setEnabled(false);
+			}
+
+		}));
+		$this->addCheck(new FormValidatorCustom($this, 'orcidClientSecret', 'required', 'plugins.generic.orcidProfile.manager.settings.orcidClientSecret.error', function ($clientSecret) {
+			if (preg_match('/^(\d|-|[a-f]){36,64}/', $clientSecret) == 1) {
+				$this->plugin->setEnabled(true);
+				return true;
+			} else {
+				$this->plugin->setEnabled(false);
+			}
+
+		}));
+
+
 	}
 
 	/**
@@ -81,19 +103,23 @@ class OrcidProfileSettingsForm extends Form {
 	}
 
 	/**
-	 * Save settings.
+	 * @copydoc Form::execute()
 	 */
-	function execute() {
+	function execute(...$functionArgs) {
 		$plugin =& $this->plugin;
 		$contextId = $this->contextId;
 		foreach (self::CONFIG_VARS as $configVar => $type) {
 			if ($configVar === 'orcidProfileAPIPath') {
 				$plugin->updateSetting($contextId, $configVar, trim($this->getData($configVar), "\"\';"), $type);
-			}
-			else {
+			} else {
 				$plugin->updateSetting($contextId, $configVar, $this->getData($configVar), $type);
 			}
 		}
+		if (strpos($this->getData("orcidProfileAPIPath"), "sandbox.orcid.org") == true) {
+			$plugin->updateSetting($contextId, "isSandBox", true, "bool");
+		}
+
+		parent::execute(...$functionArgs);
 	}
 }
 
