@@ -3,9 +3,9 @@
 /**
  * @file plugins/importexport/native/filter/AuthorNativeXmlFilter.inc.php
  *
- * Copyright (c) 2014-2016 Simon Fraser University Library
- * Copyright (c) 2000-2016 John Willinsky
- * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
+ * Copyright (c) 2014-2021 Simon Fraser University
+ * Copyright (c) 2000-2021 John Willinsky
+ * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @class AuthorNativeXmlFilter
  * @ingroup plugins_importexport_native
@@ -20,8 +20,8 @@ class AuthorNativeXmlFilter extends PKPAuthorNativeXmlFilter {
 	 * Constructor
 	 * @param $filterGroup FilterGroup
 	 */
-	function AuthorNativeXmlFilter($filterGroup) {
-		parent::PKPAuthorNativeXmlFilter($filterGroup);
+	function __construct($filterGroup) {
+		parent::__construct($filterGroup);
 	}
 
 
@@ -36,4 +36,4 @@ class AuthorNativeXmlFilter extends PKPAuthorNativeXmlFilter {
 	}
 }
 
-?>
+
